"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import Any, TYPE_CHECKING

from moovio_sdk.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .acceptdispute import (
        AcceptDisputeGlobals,
        AcceptDisputeGlobalsTypedDict,
        AcceptDisputeRequest,
        AcceptDisputeRequestTypedDict,
        AcceptDisputeResponse,
        AcceptDisputeResponseTypedDict,
    )
    from .assignaccountcountries import (
        AssignAccountCountriesGlobals,
        AssignAccountCountriesGlobalsTypedDict,
        AssignAccountCountriesRequest,
        AssignAccountCountriesRequestTypedDict,
        AssignAccountCountriesResponse,
        AssignAccountCountriesResponseTypedDict,
    )
    from .cancelschedule import (
        CancelScheduleGlobals,
        CancelScheduleGlobalsTypedDict,
        CancelScheduleRequest,
        CancelScheduleRequestTypedDict,
        CancelScheduleResponse,
        CancelScheduleResponseTypedDict,
    )
    from .completebankaccountverification import (
        CompleteBankAccountVerificationGlobals,
        CompleteBankAccountVerificationGlobalsTypedDict,
        CompleteBankAccountVerificationRequest,
        CompleteBankAccountVerificationRequestTypedDict,
        CompleteBankAccountVerificationResponse,
        CompleteBankAccountVerificationResponseTypedDict,
    )
    from .completemicrodeposits import (
        CompleteMicroDepositsGlobals,
        CompleteMicroDepositsGlobalsTypedDict,
        CompleteMicroDepositsRequest,
        CompleteMicroDepositsRequestTypedDict,
        CompleteMicroDepositsResponse,
        CompleteMicroDepositsResponseTypedDict,
    )
    from .connectaccount import (
        ConnectAccountGlobals,
        ConnectAccountGlobalsTypedDict,
        ConnectAccountRequest,
        ConnectAccountRequestTypedDict,
        ConnectAccountResponse,
        ConnectAccountResponseTypedDict,
    )
    from .createaccesstoken import (
        CreateAccessTokenGlobals,
        CreateAccessTokenGlobalsTypedDict,
        CreateAccessTokenResponse,
        CreateAccessTokenResponseTypedDict,
    )
    from .createaccount import (
        CreateAccountGlobals,
        CreateAccountGlobalsTypedDict,
        CreateAccountResponse,
        CreateAccountResponseTypedDict,
    )
    from .createapplepaysession import (
        CreateApplePaySessionGlobals,
        CreateApplePaySessionGlobalsTypedDict,
        CreateApplePaySessionRequest,
        CreateApplePaySessionRequestTypedDict,
        CreateApplePaySessionResponse,
        CreateApplePaySessionResponseTypedDict,
    )
    from .createbrand import (
        CreateBrandGlobals,
        CreateBrandGlobalsTypedDict,
        CreateBrandRequest,
        CreateBrandRequestTypedDict,
        CreateBrandResponse,
        CreateBrandResponseTypedDict,
    )
    from .createcancellation import (
        CreateCancellationGlobals,
        CreateCancellationGlobalsTypedDict,
        CreateCancellationRequest,
        CreateCancellationRequestTypedDict,
        CreateCancellationResponse,
        CreateCancellationResponseTypedDict,
    )
    from .createfeeplanagreements import (
        CreateFeePlanAgreementsGlobals,
        CreateFeePlanAgreementsGlobalsTypedDict,
        CreateFeePlanAgreementsRequest,
        CreateFeePlanAgreementsRequestTypedDict,
        CreateFeePlanAgreementsResponse,
        CreateFeePlanAgreementsResponseTypedDict,
    )
    from .createinvoice import (
        CreateInvoiceGlobals,
        CreateInvoiceGlobalsTypedDict,
        CreateInvoiceRequest,
        CreateInvoiceRequestTypedDict,
        CreateInvoiceResponse,
        CreateInvoiceResponseTypedDict,
    )
    from .createinvoicepayment import (
        CreateInvoicePaymentGlobals,
        CreateInvoicePaymentGlobalsTypedDict,
        CreateInvoicePaymentRequest,
        CreateInvoicePaymentRequestTypedDict,
        CreateInvoicePaymentResponse,
        CreateInvoicePaymentResponseTypedDict,
    )
    from .createonboardinginvite import (
        CreateOnboardingInviteGlobals,
        CreateOnboardingInviteGlobalsTypedDict,
        CreateOnboardingInviteResponse,
        CreateOnboardingInviteResponseTypedDict,
    )
    from .createpaymentlink import (
        CreatePaymentLinkGlobals,
        CreatePaymentLinkGlobalsTypedDict,
        CreatePaymentLinkRequest,
        CreatePaymentLinkRequestTypedDict,
        CreatePaymentLinkResponse,
        CreatePaymentLinkResponseTypedDict,
    )
    from .createproduct import (
        CreateProductGlobals,
        CreateProductGlobalsTypedDict,
        CreateProductRequest,
        CreateProductRequestTypedDict,
        CreateProductResponse,
        CreateProductResponseTypedDict,
    )
    from .createreceipts import (
        CreateReceiptsGlobals,
        CreateReceiptsGlobalsTypedDict,
        CreateReceiptsResponse,
        CreateReceiptsResponseTypedDict,
    )
    from .createrepresentative import (
        CreateRepresentativeGlobals,
        CreateRepresentativeGlobalsTypedDict,
        CreateRepresentativeRequest,
        CreateRepresentativeRequestTypedDict,
        CreateRepresentativeResponse,
        CreateRepresentativeResponseTypedDict,
    )
    from .createreversal import (
        CreateReversalGlobals,
        CreateReversalGlobalsTypedDict,
        CreateReversalRequest,
        CreateReversalRequestTypedDict,
        CreateReversalResponse,
        CreateReversalResponseTypedDict,
    )
    from .createschedule import (
        CreateScheduleGlobals,
        CreateScheduleGlobalsTypedDict,
        CreateScheduleRequest,
        CreateScheduleRequestTypedDict,
        CreateScheduleResponse,
        CreateScheduleResponseTypedDict,
    )
    from .createsweepconfig import (
        CreateSweepConfigGlobals,
        CreateSweepConfigGlobalsTypedDict,
        CreateSweepConfigRequest,
        CreateSweepConfigRequestTypedDict,
        CreateSweepConfigResponse,
        CreateSweepConfigResponseTypedDict,
    )
    from .createterminalapplication import (
        CreateTerminalApplicationGlobals,
        CreateTerminalApplicationGlobalsTypedDict,
        CreateTerminalApplicationResponse,
        CreateTerminalApplicationResponseTypedDict,
    )
    from .createterminalapplicationversion import (
        CreateTerminalApplicationVersionGlobals,
        CreateTerminalApplicationVersionGlobalsTypedDict,
        CreateTerminalApplicationVersionRequest,
        CreateTerminalApplicationVersionRequestTypedDict,
        CreateTerminalApplicationVersionResponse,
        CreateTerminalApplicationVersionResponseTypedDict,
    )
    from .createticket import (
        CreateTicketGlobals,
        CreateTicketGlobalsTypedDict,
        CreateTicketRequest,
        CreateTicketRequestTypedDict,
        CreateTicketResponse,
        CreateTicketResponseTypedDict,
    )
    from .createtransfer import (
        CreateTransferGlobals,
        CreateTransferGlobalsTypedDict,
        CreateTransferRequest,
        CreateTransferRequestTypedDict,
        CreateTransferResponse,
        CreateTransferResponseResult,
        CreateTransferResponseResultTypedDict,
        CreateTransferResponseTypedDict,
    )
    from .createtransferoptions import (
        CreateTransferOptionsGlobals,
        CreateTransferOptionsGlobalsTypedDict,
        CreateTransferOptionsRequest,
        CreateTransferOptionsRequestTypedDict,
        CreateTransferOptionsResponse,
        CreateTransferOptionsResponseTypedDict,
    )
    from .createwallet import (
        CreateWalletGlobals,
        CreateWalletGlobalsTypedDict,
        CreateWalletRequest,
        CreateWalletRequestTypedDict,
        CreateWalletResponse,
        CreateWalletResponseTypedDict,
    )
    from .createwebhook import (
        CreateWebhookGlobals,
        CreateWebhookGlobalsTypedDict,
        CreateWebhookResponse,
        CreateWebhookResponseTypedDict,
    )
    from .deletedisputeevidencefile import (
        DeleteDisputeEvidenceFileGlobals,
        DeleteDisputeEvidenceFileGlobalsTypedDict,
        DeleteDisputeEvidenceFileRequest,
        DeleteDisputeEvidenceFileRequestTypedDict,
        DeleteDisputeEvidenceFileResponse,
        DeleteDisputeEvidenceFileResponseTypedDict,
    )
    from .deleteimage import (
        DeleteImageGlobals,
        DeleteImageGlobalsTypedDict,
        DeleteImageRequest,
        DeleteImageRequestTypedDict,
        DeleteImageResponse,
        DeleteImageResponseTypedDict,
    )
    from .deleteinvoice import (
        DeleteInvoiceGlobals,
        DeleteInvoiceGlobalsTypedDict,
        DeleteInvoiceRequest,
        DeleteInvoiceRequestTypedDict,
        DeleteInvoiceResponse,
        DeleteInvoiceResponseTypedDict,
    )
    from .deleterepresentative import (
        DeleteRepresentativeGlobals,
        DeleteRepresentativeGlobalsTypedDict,
        DeleteRepresentativeRequest,
        DeleteRepresentativeRequestTypedDict,
        DeleteRepresentativeResponse,
        DeleteRepresentativeResponseTypedDict,
    )
    from .deleteterminalapplication import (
        DeleteTerminalApplicationGlobals,
        DeleteTerminalApplicationGlobalsTypedDict,
        DeleteTerminalApplicationRequest,
        DeleteTerminalApplicationRequestTypedDict,
        DeleteTerminalApplicationResponse,
        DeleteTerminalApplicationResponseTypedDict,
    )
    from .disablebankaccount import (
        DisableBankAccountGlobals,
        DisableBankAccountGlobalsTypedDict,
        DisableBankAccountRequest,
        DisableBankAccountRequestTypedDict,
        DisableBankAccountResponse,
        DisableBankAccountResponseTypedDict,
    )
    from .disablecapability import (
        DisableCapabilityGlobals,
        DisableCapabilityGlobalsTypedDict,
        DisableCapabilityRequest,
        DisableCapabilityRequestTypedDict,
        DisableCapabilityResponse,
        DisableCapabilityResponseTypedDict,
    )
    from .disablecard import (
        DisableCardGlobals,
        DisableCardGlobalsTypedDict,
        DisableCardRequest,
        DisableCardRequestTypedDict,
        DisableCardResponse,
        DisableCardResponseTypedDict,
    )
    from .disablepaymentlink import (
        DisablePaymentLinkGlobals,
        DisablePaymentLinkGlobalsTypedDict,
        DisablePaymentLinkRequest,
        DisablePaymentLinkRequestTypedDict,
        DisablePaymentLinkResponse,
        DisablePaymentLinkResponseTypedDict,
    )
    from .disableproduct import (
        DisableProductGlobals,
        DisableProductGlobalsTypedDict,
        DisableProductRequest,
        DisableProductRequestTypedDict,
        DisableProductResponse,
        DisableProductResponseTypedDict,
    )
    from .disablewebhook import (
        DisableWebhookGlobals,
        DisableWebhookGlobalsTypedDict,
        DisableWebhookRequest,
        DisableWebhookRequestTypedDict,
        DisableWebhookResponse,
        DisableWebhookResponseTypedDict,
    )
    from .disconnectaccount import (
        DisconnectAccountGlobals,
        DisconnectAccountGlobalsTypedDict,
        DisconnectAccountRequest,
        DisconnectAccountRequestTypedDict,
        DisconnectAccountResponse,
        DisconnectAccountResponseTypedDict,
    )
    from .generateendtoendkey import (
        GenerateEndToEndKeyGlobals,
        GenerateEndToEndKeyGlobalsTypedDict,
        GenerateEndToEndKeyRequest,
        GenerateEndToEndKeyRequestTypedDict,
        GenerateEndToEndKeyResponse,
        GenerateEndToEndKeyResponseTypedDict,
    )
    from .getaccount import (
        GetAccountGlobals,
        GetAccountGlobalsTypedDict,
        GetAccountRequest,
        GetAccountRequestTypedDict,
        GetAccountResponse,
        GetAccountResponseTypedDict,
    )
    from .getaccountcountries import (
        GetAccountCountriesGlobals,
        GetAccountCountriesGlobalsTypedDict,
        GetAccountCountriesRequest,
        GetAccountCountriesRequestTypedDict,
        GetAccountCountriesResponse,
        GetAccountCountriesResponseTypedDict,
    )
    from .getaccountterminalapplication import (
        GetAccountTerminalApplicationGlobals,
        GetAccountTerminalApplicationGlobalsTypedDict,
        GetAccountTerminalApplicationRequest,
        GetAccountTerminalApplicationRequestTypedDict,
        GetAccountTerminalApplicationResponse,
        GetAccountTerminalApplicationResponseTypedDict,
    )
    from .getadjustment import (
        GetAdjustmentGlobals,
        GetAdjustmentGlobalsTypedDict,
        GetAdjustmentRequest,
        GetAdjustmentRequestTypedDict,
        GetAdjustmentResponse,
        GetAdjustmentResponseTypedDict,
    )
    from .getapplepaymerchantdomains import (
        GetApplePayMerchantDomainsGlobals,
        GetApplePayMerchantDomainsGlobalsTypedDict,
        GetApplePayMerchantDomainsRequest,
        GetApplePayMerchantDomainsRequestTypedDict,
        GetApplePayMerchantDomainsResponse,
        GetApplePayMerchantDomainsResponseTypedDict,
    )
    from .getavatar import (
        GetAvatarGlobals,
        GetAvatarGlobalsTypedDict,
        GetAvatarRequest,
        GetAvatarRequestTypedDict,
        GetAvatarResponse,
        GetAvatarResponseTypedDict,
    )
    from .getbankaccount import (
        GetBankAccountGlobals,
        GetBankAccountGlobalsTypedDict,
        GetBankAccountRequest,
        GetBankAccountRequestTypedDict,
        GetBankAccountResponse,
        GetBankAccountResponseTypedDict,
    )
    from .getbankaccountverification import (
        GetBankAccountVerificationGlobals,
        GetBankAccountVerificationGlobalsTypedDict,
        GetBankAccountVerificationRequest,
        GetBankAccountVerificationRequestTypedDict,
        GetBankAccountVerificationResponse,
        GetBankAccountVerificationResponseTypedDict,
    )
    from .getbrand import (
        GetBrandGlobals,
        GetBrandGlobalsTypedDict,
        GetBrandRequest,
        GetBrandRequestTypedDict,
        GetBrandResponse,
        GetBrandResponseTypedDict,
    )
    from .getcancellation import (
        GetCancellationGlobals,
        GetCancellationGlobalsTypedDict,
        GetCancellationRequest,
        GetCancellationRequestTypedDict,
        GetCancellationResponse,
        GetCancellationResponseTypedDict,
    )
    from .getcapability import (
        GetCapabilityGlobals,
        GetCapabilityGlobalsTypedDict,
        GetCapabilityRequest,
        GetCapabilityRequestTypedDict,
        GetCapabilityResponse,
        GetCapabilityResponseTypedDict,
    )
    from .getcard import (
        GetCardGlobals,
        GetCardGlobalsTypedDict,
        GetCardRequest,
        GetCardRequestTypedDict,
        GetCardResponse,
        GetCardResponseTypedDict,
    )
    from .getdispute import (
        GetDisputeGlobals,
        GetDisputeGlobalsTypedDict,
        GetDisputeRequest,
        GetDisputeRequestTypedDict,
        GetDisputeResponse,
        GetDisputeResponseTypedDict,
    )
    from .getdisputeevidence import (
        GetDisputeEvidenceGlobals,
        GetDisputeEvidenceGlobalsTypedDict,
        GetDisputeEvidenceRequest,
        GetDisputeEvidenceRequestTypedDict,
        GetDisputeEvidenceResponse,
        GetDisputeEvidenceResponseTypedDict,
    )
    from .getdisputeevidencedata import (
        GetDisputeEvidenceDataGlobals,
        GetDisputeEvidenceDataGlobalsTypedDict,
        GetDisputeEvidenceDataRequest,
        GetDisputeEvidenceDataRequestTypedDict,
        GetDisputeEvidenceDataResponse,
        GetDisputeEvidenceDataResponseResult,
        GetDisputeEvidenceDataResponseResultTypedDict,
        GetDisputeEvidenceDataResponseTypedDict,
    )
    from .getenrichmentaddress import (
        GetEnrichmentAddressGlobals,
        GetEnrichmentAddressGlobalsTypedDict,
        GetEnrichmentAddressRequest,
        GetEnrichmentAddressRequestTypedDict,
        GetEnrichmentAddressResponse,
        GetEnrichmentAddressResponseTypedDict,
    )
    from .getenrichmentprofile import (
        GetEnrichmentProfileGlobals,
        GetEnrichmentProfileGlobalsTypedDict,
        GetEnrichmentProfileRequest,
        GetEnrichmentProfileRequestTypedDict,
        GetEnrichmentProfileResponse,
        GetEnrichmentProfileResponseTypedDict,
    )
    from .getfiledetails import (
        GetFileDetailsGlobals,
        GetFileDetailsGlobalsTypedDict,
        GetFileDetailsRequest,
        GetFileDetailsRequestTypedDict,
        GetFileDetailsResponse,
        GetFileDetailsResponseTypedDict,
    )
    from .getfullissuedcard import (
        GetFullIssuedCardGlobals,
        GetFullIssuedCardGlobalsTypedDict,
        GetFullIssuedCardRequest,
        GetFullIssuedCardRequestTypedDict,
        GetFullIssuedCardResponse,
        GetFullIssuedCardResponseTypedDict,
    )
    from .getimagemetadata import (
        GetImageMetadataGlobals,
        GetImageMetadataGlobalsTypedDict,
        GetImageMetadataRequest,
        GetImageMetadataRequestTypedDict,
        GetImageMetadataResponse,
        GetImageMetadataResponseTypedDict,
    )
    from .getinvoice import (
        GetInvoiceGlobals,
        GetInvoiceGlobalsTypedDict,
        GetInvoiceRequest,
        GetInvoiceRequestTypedDict,
        GetInvoiceResponse,
        GetInvoiceResponseTypedDict,
    )
    from .getissuedcard import (
        GetIssuedCardGlobals,
        GetIssuedCardGlobalsTypedDict,
        GetIssuedCardRequest,
        GetIssuedCardRequestTypedDict,
        GetIssuedCardResponse,
        GetIssuedCardResponseTypedDict,
    )
    from .getissuedcardauthorization import (
        GetIssuedCardAuthorizationGlobals,
        GetIssuedCardAuthorizationGlobalsTypedDict,
        GetIssuedCardAuthorizationRequest,
        GetIssuedCardAuthorizationRequestTypedDict,
        GetIssuedCardAuthorizationResponse,
        GetIssuedCardAuthorizationResponseTypedDict,
    )
    from .getissuedcardtransaction import (
        GetIssuedCardTransactionGlobals,
        GetIssuedCardTransactionGlobalsTypedDict,
        GetIssuedCardTransactionRequest,
        GetIssuedCardTransactionRequestTypedDict,
        GetIssuedCardTransactionResponse,
        GetIssuedCardTransactionResponseTypedDict,
    )
    from .getmerchantprocessingagreement import (
        GetMerchantProcessingAgreementGlobals,
        GetMerchantProcessingAgreementGlobalsTypedDict,
        GetMerchantProcessingAgreementRequest,
        GetMerchantProcessingAgreementRequestTypedDict,
        GetMerchantProcessingAgreementResponse,
        GetMerchantProcessingAgreementResponseTypedDict,
    )
    from .getonboardinginvite import (
        GetOnboardingInviteGlobals,
        GetOnboardingInviteGlobalsTypedDict,
        GetOnboardingInviteRequest,
        GetOnboardingInviteRequestTypedDict,
        GetOnboardingInviteResponse,
        GetOnboardingInviteResponseTypedDict,
    )
    from .getpaymentlink import (
        GetPaymentLinkGlobals,
        GetPaymentLinkGlobalsTypedDict,
        GetPaymentLinkRequest,
        GetPaymentLinkRequestTypedDict,
        GetPaymentLinkResponse,
        GetPaymentLinkResponseTypedDict,
    )
    from .getpaymentlinkqrcode import (
        GetPaymentLinkQRCodeGlobals,
        GetPaymentLinkQRCodeGlobalsTypedDict,
        GetPaymentLinkQRCodeRequest,
        GetPaymentLinkQRCodeRequestTypedDict,
        GetPaymentLinkQRCodeResponse,
        GetPaymentLinkQRCodeResponseResult,
        GetPaymentLinkQRCodeResponseResultTypedDict,
        GetPaymentLinkQRCodeResponseTypedDict,
    )
    from .getpaymentmethod import (
        GetPaymentMethodGlobals,
        GetPaymentMethodGlobalsTypedDict,
        GetPaymentMethodRequest,
        GetPaymentMethodRequestTypedDict,
        GetPaymentMethodResponse,
        GetPaymentMethodResponseTypedDict,
    )
    from .getproduct import (
        GetProductGlobals,
        GetProductGlobalsTypedDict,
        GetProductRequest,
        GetProductRequestTypedDict,
        GetProductResponse,
        GetProductResponseTypedDict,
    )
    from .getpublicimage import (
        GetPublicImageRequest,
        GetPublicImageRequestTypedDict,
        GetPublicImageResponse,
        GetPublicImageResponseResult,
        GetPublicImageResponseResultTypedDict,
        GetPublicImageResponseTypedDict,
    )
    from .getrefund import (
        GetRefundGlobals,
        GetRefundGlobalsTypedDict,
        GetRefundRequest,
        GetRefundRequestTypedDict,
        GetRefundResponse,
        GetRefundResponseTypedDict,
    )
    from .getrepresentative import (
        GetRepresentativeGlobals,
        GetRepresentativeGlobalsTypedDict,
        GetRepresentativeRequest,
        GetRepresentativeRequestTypedDict,
        GetRepresentativeResponse,
        GetRepresentativeResponseTypedDict,
    )
    from .getresidual import (
        GetResidualGlobals,
        GetResidualGlobalsTypedDict,
        GetResidualRequest,
        GetResidualRequestTypedDict,
        GetResidualResponse,
        GetResidualResponseTypedDict,
    )
    from .getscheduledoccurrence import (
        GetScheduledOccurrenceGlobals,
        GetScheduledOccurrenceGlobalsTypedDict,
        GetScheduledOccurrenceRequest,
        GetScheduledOccurrenceRequestTypedDict,
        GetScheduledOccurrenceResponse,
        GetScheduledOccurrenceResponseTypedDict,
    )
    from .getschedules import (
        GetSchedulesGlobals,
        GetSchedulesGlobalsTypedDict,
        GetSchedulesRequest,
        GetSchedulesRequestTypedDict,
        GetSchedulesResponse,
        GetSchedulesResponseTypedDict,
    )
    from .getstatement import (
        GetStatementGlobals,
        GetStatementGlobalsTypedDict,
        GetStatementRequest,
        GetStatementRequestTypedDict,
        GetStatementResponse,
        GetStatementResponseResult,
        GetStatementResponseResultTypedDict,
        GetStatementResponseTypedDict,
    )
    from .getsweep import (
        GetSweepGlobals,
        GetSweepGlobalsTypedDict,
        GetSweepRequest,
        GetSweepRequestTypedDict,
        GetSweepResponse,
        GetSweepResponseTypedDict,
    )
    from .getsweepconfig import (
        GetSweepConfigGlobals,
        GetSweepConfigGlobalsTypedDict,
        GetSweepConfigRequest,
        GetSweepConfigRequestTypedDict,
        GetSweepConfigResponse,
        GetSweepConfigResponseTypedDict,
    )
    from .getterminalapplication import (
        GetTerminalApplicationGlobals,
        GetTerminalApplicationGlobalsTypedDict,
        GetTerminalApplicationRequest,
        GetTerminalApplicationRequestTypedDict,
        GetTerminalApplicationResponse,
        GetTerminalApplicationResponseTypedDict,
    )
    from .getterminalconfiguration import (
        GetTerminalConfigurationGlobals,
        GetTerminalConfigurationGlobalsTypedDict,
        GetTerminalConfigurationRequest,
        GetTerminalConfigurationRequestTypedDict,
        GetTerminalConfigurationResponse,
        GetTerminalConfigurationResponseTypedDict,
    )
    from .gettermsofservicetoken import (
        GetTermsOfServiceTokenGlobals,
        GetTermsOfServiceTokenGlobalsTypedDict,
        GetTermsOfServiceTokenRequest,
        GetTermsOfServiceTokenRequestTypedDict,
        GetTermsOfServiceTokenResponse,
        GetTermsOfServiceTokenResponseTypedDict,
    )
    from .getticket import (
        GetTicketGlobals,
        GetTicketGlobalsTypedDict,
        GetTicketRequest,
        GetTicketRequestTypedDict,
        GetTicketResponse,
        GetTicketResponseTypedDict,
    )
    from .gettransfer import (
        GetTransferGlobals,
        GetTransferGlobalsTypedDict,
        GetTransferRequest,
        GetTransferRequestTypedDict,
        GetTransferResponse,
        GetTransferResponseTypedDict,
    )
    from .getunderwriting import (
        GetUnderwritingGlobals,
        GetUnderwritingGlobalsTypedDict,
        GetUnderwritingRequest,
        GetUnderwritingRequestTypedDict,
        GetUnderwritingResponse,
        GetUnderwritingResponseTypedDict,
    )
    from .getwallet import (
        GetWalletGlobals,
        GetWalletGlobalsTypedDict,
        GetWalletRequest,
        GetWalletRequestTypedDict,
        GetWalletResponse,
        GetWalletResponseTypedDict,
    )
    from .getwallettransaction import (
        GetWalletTransactionGlobals,
        GetWalletTransactionGlobalsTypedDict,
        GetWalletTransactionRequest,
        GetWalletTransactionRequestTypedDict,
        GetWalletTransactionResponse,
        GetWalletTransactionResponseTypedDict,
    )
    from .getwebhook import (
        GetWebhookGlobals,
        GetWebhookGlobalsTypedDict,
        GetWebhookRequest,
        GetWebhookRequestTypedDict,
        GetWebhookResponse,
        GetWebhookResponseTypedDict,
    )
    from .getwebhooksecret import (
        GetWebhookSecretGlobals,
        GetWebhookSecretGlobalsTypedDict,
        GetWebhookSecretRequest,
        GetWebhookSecretRequestTypedDict,
        GetWebhookSecretResponse,
        GetWebhookSecretResponseTypedDict,
    )
    from .initiatebankaccountverification import (
        InitiateBankAccountVerificationGlobals,
        InitiateBankAccountVerificationGlobalsTypedDict,
        InitiateBankAccountVerificationRequest,
        InitiateBankAccountVerificationRequestTypedDict,
        InitiateBankAccountVerificationResponse,
        InitiateBankAccountVerificationResponseTypedDict,
    )
    from .initiatemicrodeposits import (
        InitiateMicroDepositsGlobals,
        InitiateMicroDepositsGlobalsTypedDict,
        InitiateMicroDepositsRequest,
        InitiateMicroDepositsRequestTypedDict,
        InitiateMicroDepositsResponse,
        InitiateMicroDepositsResponseTypedDict,
    )
    from .initiaterefund import (
        InitiateRefundGlobals,
        InitiateRefundGlobalsTypedDict,
        InitiateRefundRequest,
        InitiateRefundRequestTypedDict,
        InitiateRefundResponse,
        InitiateRefundResponseResult,
        InitiateRefundResponseResultTypedDict,
        InitiateRefundResponseTypedDict,
    )
    from .linkaccountterminalapplication import (
        LinkAccountTerminalApplicationGlobals,
        LinkAccountTerminalApplicationGlobalsTypedDict,
        LinkAccountTerminalApplicationRequest,
        LinkAccountTerminalApplicationRequestTypedDict,
        LinkAccountTerminalApplicationResponse,
        LinkAccountTerminalApplicationResponseTypedDict,
    )
    from .linkapplepaytoken import (
        LinkApplePayTokenGlobals,
        LinkApplePayTokenGlobalsTypedDict,
        LinkApplePayTokenRequest,
        LinkApplePayTokenRequestTypedDict,
        LinkApplePayTokenResponse,
        LinkApplePayTokenResponseTypedDict,
    )
    from .linkbankaccount import (
        LinkBankAccountGlobals,
        LinkBankAccountGlobalsTypedDict,
        LinkBankAccountRequest,
        LinkBankAccountRequestTypedDict,
        LinkBankAccountResponse,
        LinkBankAccountResponseTypedDict,
    )
    from .linkcard import (
        LinkCardGlobals,
        LinkCardGlobalsTypedDict,
        LinkCardRequest,
        LinkCardRequestTypedDict,
        LinkCardResponse,
        LinkCardResponseTypedDict,
    )
    from .listaccounts import (
        ListAccountsGlobals,
        ListAccountsGlobalsTypedDict,
        ListAccountsRequest,
        ListAccountsRequestTypedDict,
        ListAccountsResponse,
        ListAccountsResponseTypedDict,
    )
    from .listaccountterminalapplications import (
        ListAccountTerminalApplicationsGlobals,
        ListAccountTerminalApplicationsGlobalsTypedDict,
        ListAccountTerminalApplicationsRequest,
        ListAccountTerminalApplicationsRequestTypedDict,
        ListAccountTerminalApplicationsResponse,
        ListAccountTerminalApplicationsResponseTypedDict,
    )
    from .listadjustments import (
        ListAdjustmentsGlobals,
        ListAdjustmentsGlobalsTypedDict,
        ListAdjustmentsRequest,
        ListAdjustmentsRequestTypedDict,
        ListAdjustmentsResponse,
        ListAdjustmentsResponseTypedDict,
    )
    from .listbankaccounts import (
        ListBankAccountsGlobals,
        ListBankAccountsGlobalsTypedDict,
        ListBankAccountsRequest,
        ListBankAccountsRequestTypedDict,
        ListBankAccountsResponse,
        ListBankAccountsResponseTypedDict,
    )
    from .listcapabilities import (
        ListCapabilitiesGlobals,
        ListCapabilitiesGlobalsTypedDict,
        ListCapabilitiesRequest,
        ListCapabilitiesRequestTypedDict,
        ListCapabilitiesResponse,
        ListCapabilitiesResponseTypedDict,
    )
    from .listcards import (
        ListCardsGlobals,
        ListCardsGlobalsTypedDict,
        ListCardsRequest,
        ListCardsRequestTypedDict,
        ListCardsResponse,
        ListCardsResponseTypedDict,
    )
    from .listconnectedaccountsforaccount import (
        ListConnectedAccountsForAccountGlobals,
        ListConnectedAccountsForAccountGlobalsTypedDict,
        ListConnectedAccountsForAccountRequest,
        ListConnectedAccountsForAccountRequestTypedDict,
        ListConnectedAccountsForAccountResponse,
        ListConnectedAccountsForAccountResponseTypedDict,
    )
    from .listdisputeevidence import (
        ListDisputeEvidenceGlobals,
        ListDisputeEvidenceGlobalsTypedDict,
        ListDisputeEvidenceRequest,
        ListDisputeEvidenceRequestTypedDict,
        ListDisputeEvidenceResponse,
        ListDisputeEvidenceResponseTypedDict,
    )
    from .listdisputes import (
        ListDisputesGlobals,
        ListDisputesGlobalsTypedDict,
        ListDisputesRequest,
        ListDisputesRequestTypedDict,
        ListDisputesResponse,
        ListDisputesResponseTypedDict,
    )
    from .listeventtypes import (
        ListEventTypesGlobals,
        ListEventTypesGlobalsTypedDict,
        ListEventTypesRequest,
        ListEventTypesRequestTypedDict,
        ListEventTypesResponse,
        ListEventTypesResponseTypedDict,
    )
    from .listfeeplanagreements import (
        ListFeePlanAgreementsGlobals,
        ListFeePlanAgreementsGlobalsTypedDict,
        ListFeePlanAgreementsRequest,
        ListFeePlanAgreementsRequestTypedDict,
        ListFeePlanAgreementsResponse,
        ListFeePlanAgreementsResponseTypedDict,
    )
    from .listfeeplans import (
        ListFeePlansGlobals,
        ListFeePlansGlobalsTypedDict,
        ListFeePlansRequest,
        ListFeePlansRequestTypedDict,
        ListFeePlansResponse,
        ListFeePlansResponseTypedDict,
    )
    from .listfeerevenue import (
        ListFeeRevenueGlobals,
        ListFeeRevenueGlobalsTypedDict,
        ListFeeRevenueRequest,
        ListFeeRevenueRequestTypedDict,
        ListFeeRevenueResponse,
        ListFeeRevenueResponseTypedDict,
    )
    from .listfeesfetch import (
        ListFeesFetchGlobals,
        ListFeesFetchGlobalsTypedDict,
        ListFeesFetchRequest,
        ListFeesFetchRequestTypedDict,
        ListFeesFetchResponse,
        ListFeesFetchResponseTypedDict,
    )
    from .listfiles import (
        ListFilesGlobals,
        ListFilesGlobalsTypedDict,
        ListFilesRequest,
        ListFilesRequestTypedDict,
        ListFilesResponse,
        ListFilesResponseTypedDict,
    )
    from .listimagemetadata import (
        ListImageMetadataGlobals,
        ListImageMetadataGlobalsTypedDict,
        ListImageMetadataRequest,
        ListImageMetadataRequestTypedDict,
        ListImageMetadataResponse,
        ListImageMetadataResponseTypedDict,
    )
    from .listindustries import (
        ListIndustriesGlobals,
        ListIndustriesGlobalsTypedDict,
        ListIndustriesRequest,
        ListIndustriesRequestTypedDict,
        ListIndustriesResponse,
        ListIndustriesResponseTypedDict,
    )
    from .listinstitutions import (
        ListInstitutionsGlobals,
        ListInstitutionsGlobalsTypedDict,
        ListInstitutionsRequest,
        ListInstitutionsRequestTypedDict,
        ListInstitutionsResponse,
        ListInstitutionsResponseTypedDict,
    )
    from .listinvoicepayments import (
        ListInvoicePaymentsGlobals,
        ListInvoicePaymentsGlobalsTypedDict,
        ListInvoicePaymentsRequest,
        ListInvoicePaymentsRequestTypedDict,
        ListInvoicePaymentsResponse,
        ListInvoicePaymentsResponseTypedDict,
    )
    from .listinvoices import (
        ListInvoicesGlobals,
        ListInvoicesGlobalsTypedDict,
        ListInvoicesRequest,
        ListInvoicesRequestTypedDict,
        ListInvoicesResponse,
        ListInvoicesResponseTypedDict,
    )
    from .listissuedcardauthorizationevents import (
        ListIssuedCardAuthorizationEventsGlobals,
        ListIssuedCardAuthorizationEventsGlobalsTypedDict,
        ListIssuedCardAuthorizationEventsRequest,
        ListIssuedCardAuthorizationEventsRequestTypedDict,
        ListIssuedCardAuthorizationEventsResponse,
        ListIssuedCardAuthorizationEventsResponseTypedDict,
    )
    from .listissuedcardauthorizations import (
        ListIssuedCardAuthorizationsGlobals,
        ListIssuedCardAuthorizationsGlobalsTypedDict,
        ListIssuedCardAuthorizationsRequest,
        ListIssuedCardAuthorizationsRequestTypedDict,
        ListIssuedCardAuthorizationsResponse,
        ListIssuedCardAuthorizationsResponseTypedDict,
    )
    from .listissuedcards import (
        ListIssuedCardsGlobals,
        ListIssuedCardsGlobalsTypedDict,
        ListIssuedCardsRequest,
        ListIssuedCardsRequestTypedDict,
        ListIssuedCardsResponse,
        ListIssuedCardsResponseTypedDict,
    )
    from .listissuedcardtransactions import (
        ListIssuedCardTransactionsGlobals,
        ListIssuedCardTransactionsGlobalsTypedDict,
        ListIssuedCardTransactionsRequest,
        ListIssuedCardTransactionsRequestTypedDict,
        ListIssuedCardTransactionsResponse,
        ListIssuedCardTransactionsResponseTypedDict,
    )
    from .listonboardinginvites import (
        ListOnboardingInvitesGlobals,
        ListOnboardingInvitesGlobalsTypedDict,
        ListOnboardingInvitesRequest,
        ListOnboardingInvitesRequestTypedDict,
        ListOnboardingInvitesResponse,
        ListOnboardingInvitesResponseTypedDict,
    )
    from .listpartnerpricingagreements import (
        ListPartnerPricingAgreementsGlobals,
        ListPartnerPricingAgreementsGlobalsTypedDict,
        ListPartnerPricingAgreementsRequest,
        ListPartnerPricingAgreementsRequestTypedDict,
        ListPartnerPricingAgreementsResponse,
        ListPartnerPricingAgreementsResponseTypedDict,
    )
    from .listpaymentlinks import (
        ListPaymentLinksGlobals,
        ListPaymentLinksGlobalsTypedDict,
        ListPaymentLinksRequest,
        ListPaymentLinksRequestTypedDict,
        ListPaymentLinksResponse,
        ListPaymentLinksResponseTypedDict,
    )
    from .listpaymentmethods import (
        ListPaymentMethodsGlobals,
        ListPaymentMethodsGlobalsTypedDict,
        ListPaymentMethodsRequest,
        ListPaymentMethodsRequestTypedDict,
        ListPaymentMethodsResponse,
        ListPaymentMethodsResponseTypedDict,
    )
    from .listproducts import (
        ListProductsGlobals,
        ListProductsGlobalsTypedDict,
        ListProductsRequest,
        ListProductsRequestTypedDict,
        ListProductsResponse,
        ListProductsResponseTypedDict,
    )
    from .listreceipts import (
        ListReceiptsGlobals,
        ListReceiptsGlobalsTypedDict,
        ListReceiptsRequest,
        ListReceiptsRequestTypedDict,
        ListReceiptsResponse,
        ListReceiptsResponseTypedDict,
    )
    from .listrefunds import (
        ListRefundsGlobals,
        ListRefundsGlobalsTypedDict,
        ListRefundsRequest,
        ListRefundsRequestTypedDict,
        ListRefundsResponse,
        ListRefundsResponseTypedDict,
    )
    from .listrepresentatives import (
        ListRepresentativesGlobals,
        ListRepresentativesGlobalsTypedDict,
        ListRepresentativesRequest,
        ListRepresentativesRequestTypedDict,
        ListRepresentativesResponse,
        ListRepresentativesResponseTypedDict,
    )
    from .listresidualfees import (
        ListResidualFeesGlobals,
        ListResidualFeesGlobalsTypedDict,
        ListResidualFeesRequest,
        ListResidualFeesRequestTypedDict,
        ListResidualFeesResponse,
        ListResidualFeesResponseTypedDict,
    )
    from .listresiduals import (
        ListResidualsGlobals,
        ListResidualsGlobalsTypedDict,
        ListResidualsRequest,
        ListResidualsRequestTypedDict,
        ListResidualsResponse,
        ListResidualsResponseTypedDict,
    )
    from .listschedules import (
        Hydrate,
        ListSchedulesGlobals,
        ListSchedulesGlobalsTypedDict,
        ListSchedulesRequest,
        ListSchedulesRequestTypedDict,
        ListSchedulesResponse,
        ListSchedulesResponseTypedDict,
    )
    from .liststatements import (
        ListStatementsGlobals,
        ListStatementsGlobalsTypedDict,
        ListStatementsRequest,
        ListStatementsRequestTypedDict,
        ListStatementsResponse,
        ListStatementsResponseTypedDict,
    )
    from .listsweepconfigs import (
        ListSweepConfigsGlobals,
        ListSweepConfigsGlobalsTypedDict,
        ListSweepConfigsRequest,
        ListSweepConfigsRequestTypedDict,
        ListSweepConfigsResponse,
        ListSweepConfigsResponseTypedDict,
    )
    from .listsweeps import (
        ListSweepsGlobals,
        ListSweepsGlobalsTypedDict,
        ListSweepsRequest,
        ListSweepsRequestTypedDict,
        ListSweepsResponse,
        ListSweepsResponseTypedDict,
    )
    from .listterminalapplications import (
        ListTerminalApplicationsGlobals,
        ListTerminalApplicationsGlobalsTypedDict,
        ListTerminalApplicationsRequest,
        ListTerminalApplicationsRequestTypedDict,
        ListTerminalApplicationsResponse,
        ListTerminalApplicationsResponseTypedDict,
    )
    from .listticketmessages import (
        ListTicketMessagesGlobals,
        ListTicketMessagesGlobalsTypedDict,
        ListTicketMessagesRequest,
        ListTicketMessagesRequestTypedDict,
        ListTicketMessagesResponse,
        ListTicketMessagesResponseTypedDict,
    )
    from .listtickets import (
        ListTicketsGlobals,
        ListTicketsGlobalsTypedDict,
        ListTicketsRequest,
        ListTicketsRequestTypedDict,
        ListTicketsResponse,
        ListTicketsResponseBody,
        ListTicketsResponseBodyTypedDict,
        ListTicketsResponseTypedDict,
    )
    from .listtransfers import (
        ListTransfersGlobals,
        ListTransfersGlobalsTypedDict,
        ListTransfersRequest,
        ListTransfersRequestTypedDict,
        ListTransfersResponse,
        ListTransfersResponseTypedDict,
    )
    from .listwallets import (
        ListWalletsGlobals,
        ListWalletsGlobalsTypedDict,
        ListWalletsRequest,
        ListWalletsRequestTypedDict,
        ListWalletsResponse,
        ListWalletsResponseTypedDict,
    )
    from .listwallettransactions import (
        ListWalletTransactionsGlobals,
        ListWalletTransactionsGlobalsTypedDict,
        ListWalletTransactionsRequest,
        ListWalletTransactionsRequestTypedDict,
        ListWalletTransactionsResponse,
        ListWalletTransactionsResponseTypedDict,
    )
    from .listwebhooks import (
        ListWebhooksGlobals,
        ListWebhooksGlobalsTypedDict,
        ListWebhooksRequest,
        ListWebhooksRequestTypedDict,
        ListWebhooksResponse,
        ListWebhooksResponseTypedDict,
    )
    from .ping import (
        PingGlobals,
        PingGlobalsTypedDict,
        PingRequest,
        PingRequestTypedDict,
        PingResponse,
        PingResponseTypedDict,
    )
    from .pingwebhook import (
        PingWebhookGlobals,
        PingWebhookGlobalsTypedDict,
        PingWebhookRequest,
        PingWebhookRequestTypedDict,
        PingWebhookResponse,
        PingWebhookResponseTypedDict,
    )
    from .registerapplepaymerchantdomains import (
        RegisterApplePayMerchantDomainsGlobals,
        RegisterApplePayMerchantDomainsGlobalsTypedDict,
        RegisterApplePayMerchantDomainsRequest,
        RegisterApplePayMerchantDomainsRequestTypedDict,
        RegisterApplePayMerchantDomainsResponse,
        RegisterApplePayMerchantDomainsResponseTypedDict,
    )
    from .requestcapabilities import (
        RequestCapabilitiesGlobals,
        RequestCapabilitiesGlobalsTypedDict,
        RequestCapabilitiesRequest,
        RequestCapabilitiesRequestTypedDict,
        RequestCapabilitiesResponse,
        RequestCapabilitiesResponseTypedDict,
    )
    from .requestcard import (
        RequestCardGlobals,
        RequestCardGlobalsTypedDict,
        RequestCardRequest,
        RequestCardRequestTypedDict,
        RequestCardResponse,
        RequestCardResponseTypedDict,
    )
    from .retrievefees import (
        RetrieveFeesGlobals,
        RetrieveFeesGlobalsTypedDict,
        RetrieveFeesRequest,
        RetrieveFeesRequestTypedDict,
        RetrieveFeesResponse,
        RetrieveFeesResponseTypedDict,
    )
    from .revokeaccesstoken import (
        RevokeAccessTokenGlobals,
        RevokeAccessTokenGlobalsTypedDict,
        RevokeAccessTokenResponse,
        RevokeAccessTokenResponseTypedDict,
    )
    from .revokeonboardinginvite import (
        RevokeOnboardingInviteGlobals,
        RevokeOnboardingInviteGlobalsTypedDict,
        RevokeOnboardingInviteRequest,
        RevokeOnboardingInviteRequestTypedDict,
        RevokeOnboardingInviteResponse,
        RevokeOnboardingInviteResponseTypedDict,
    )
    from .saveunderwriting import (
        SaveUnderwritingGlobals,
        SaveUnderwritingGlobalsTypedDict,
        SaveUnderwritingRequest,
        SaveUnderwritingRequestTypedDict,
        SaveUnderwritingResponse,
        SaveUnderwritingResponseTypedDict,
    )
    from .searchinstitutions import (
        SearchInstitutionsGlobals,
        SearchInstitutionsGlobalsTypedDict,
        SearchInstitutionsRequest,
        SearchInstitutionsRequestTypedDict,
        SearchInstitutionsResponse,
        SearchInstitutionsResponseTypedDict,
    )
    from .submitdisputeevidence import (
        SubmitDisputeEvidenceGlobals,
        SubmitDisputeEvidenceGlobalsTypedDict,
        SubmitDisputeEvidenceRequest,
        SubmitDisputeEvidenceRequestTypedDict,
        SubmitDisputeEvidenceResponse,
        SubmitDisputeEvidenceResponseTypedDict,
    )
    from .testendtoendtoken import (
        TestEndToEndTokenGlobals,
        TestEndToEndTokenGlobalsTypedDict,
        TestEndToEndTokenResponse,
        TestEndToEndTokenResponseTypedDict,
    )
    from .updateaccount import (
        UpdateAccountGlobals,
        UpdateAccountGlobalsTypedDict,
        UpdateAccountRequest,
        UpdateAccountRequestTypedDict,
        UpdateAccountResponse,
        UpdateAccountResponseTypedDict,
    )
    from .updateapplepaymerchantdomains import (
        UpdateApplePayMerchantDomainsGlobals,
        UpdateApplePayMerchantDomainsGlobalsTypedDict,
        UpdateApplePayMerchantDomainsRequest,
        UpdateApplePayMerchantDomainsRequestTypedDict,
        UpdateApplePayMerchantDomainsResponse,
        UpdateApplePayMerchantDomainsResponseTypedDict,
    )
    from .updatecard import (
        UpdateCardGlobals,
        UpdateCardGlobalsTypedDict,
        UpdateCardRequest,
        UpdateCardRequestTypedDict,
        UpdateCardResponse,
        UpdateCardResponseTypedDict,
    )
    from .updatedisputeevidence import (
        UpdateDisputeEvidenceGlobals,
        UpdateDisputeEvidenceGlobalsTypedDict,
        UpdateDisputeEvidenceRequest,
        UpdateDisputeEvidenceRequestTypedDict,
        UpdateDisputeEvidenceResponse,
        UpdateDisputeEvidenceResponseTypedDict,
    )
    from .updateimage import (
        UpdateImageGlobals,
        UpdateImageGlobalsTypedDict,
        UpdateImageRequest,
        UpdateImageRequestTypedDict,
        UpdateImageResponse,
        UpdateImageResponseTypedDict,
    )
    from .updateimagemetadata import (
        UpdateImageMetadataGlobals,
        UpdateImageMetadataGlobalsTypedDict,
        UpdateImageMetadataRequest,
        UpdateImageMetadataRequestTypedDict,
        UpdateImageMetadataResponse,
        UpdateImageMetadataResponseTypedDict,
    )
    from .updateinvoice import (
        UpdateInvoiceGlobals,
        UpdateInvoiceGlobalsTypedDict,
        UpdateInvoiceRequest,
        UpdateInvoiceRequestTypedDict,
        UpdateInvoiceResponse,
        UpdateInvoiceResponseTypedDict,
    )
    from .updateissuedcard import (
        UpdateIssuedCardGlobals,
        UpdateIssuedCardGlobalsTypedDict,
        UpdateIssuedCardRequest,
        UpdateIssuedCardRequestTypedDict,
        UpdateIssuedCardResponse,
        UpdateIssuedCardResponseTypedDict,
    )
    from .updatepaymentlink import (
        UpdatePaymentLinkGlobals,
        UpdatePaymentLinkGlobalsTypedDict,
        UpdatePaymentLinkRequest,
        UpdatePaymentLinkRequestTypedDict,
        UpdatePaymentLinkResponse,
        UpdatePaymentLinkResponseTypedDict,
    )
    from .updateproduct import (
        UpdateProductGlobals,
        UpdateProductGlobalsTypedDict,
        UpdateProductRequest,
        UpdateProductRequestTypedDict,
        UpdateProductResponse,
        UpdateProductResponseTypedDict,
    )
    from .updaterepresentative import (
        UpdateRepresentativeGlobals,
        UpdateRepresentativeGlobalsTypedDict,
        UpdateRepresentativeRequest,
        UpdateRepresentativeRequestTypedDict,
        UpdateRepresentativeResponse,
        UpdateRepresentativeResponseTypedDict,
    )
    from .updateschedule import (
        UpdateScheduleGlobals,
        UpdateScheduleGlobalsTypedDict,
        UpdateScheduleRequest,
        UpdateScheduleRequestTypedDict,
        UpdateScheduleResponse,
        UpdateScheduleResponseTypedDict,
    )
    from .updatesweepconfig import (
        UpdateSweepConfigGlobals,
        UpdateSweepConfigGlobalsTypedDict,
        UpdateSweepConfigRequest,
        UpdateSweepConfigRequestTypedDict,
        UpdateSweepConfigResponse,
        UpdateSweepConfigResponseTypedDict,
    )
    from .updateticket import (
        UpdateTicketGlobals,
        UpdateTicketGlobalsTypedDict,
        UpdateTicketRequest,
        UpdateTicketRequestTypedDict,
        UpdateTicketResponse,
        UpdateTicketResponseTypedDict,
    )
    from .updatetransfer import (
        UpdateTransferGlobals,
        UpdateTransferGlobalsTypedDict,
        UpdateTransferRequest,
        UpdateTransferRequestTypedDict,
        UpdateTransferResponse,
        UpdateTransferResponseTypedDict,
    )
    from .updatewallet import (
        UpdateWalletGlobals,
        UpdateWalletGlobalsTypedDict,
        UpdateWalletRequest,
        UpdateWalletRequestTypedDict,
        UpdateWalletResponse,
        UpdateWalletResponseTypedDict,
    )
    from .updatewebhook import (
        UpdateWebhookGlobals,
        UpdateWebhookGlobalsTypedDict,
        UpdateWebhookRequest,
        UpdateWebhookRequestTypedDict,
        UpdateWebhookResponse,
        UpdateWebhookResponseTypedDict,
    )
    from .uploaddisputeevidencefile import (
        UploadDisputeEvidenceFileGlobals,
        UploadDisputeEvidenceFileGlobalsTypedDict,
        UploadDisputeEvidenceFileRequest,
        UploadDisputeEvidenceFileRequestTypedDict,
        UploadDisputeEvidenceFileResponse,
        UploadDisputeEvidenceFileResponseTypedDict,
    )
    from .uploaddisputeevidencetext import (
        UploadDisputeEvidenceTextGlobals,
        UploadDisputeEvidenceTextGlobalsTypedDict,
        UploadDisputeEvidenceTextRequest,
        UploadDisputeEvidenceTextRequestTypedDict,
        UploadDisputeEvidenceTextResponse,
        UploadDisputeEvidenceTextResponseTypedDict,
    )
    from .uploadfile import (
        UploadFileGlobals,
        UploadFileGlobalsTypedDict,
        UploadFileRequest,
        UploadFileRequestTypedDict,
        UploadFileResponse,
        UploadFileResponseTypedDict,
    )
    from .uploadimage import (
        UploadImageGlobals,
        UploadImageGlobalsTypedDict,
        UploadImageRequest,
        UploadImageRequestTypedDict,
        UploadImageResponse,
        UploadImageResponseTypedDict,
    )
    from .upsertbrand import (
        UpsertBrandGlobals,
        UpsertBrandGlobalsTypedDict,
        UpsertBrandRequest,
        UpsertBrandRequestTypedDict,
        UpsertBrandResponse,
        UpsertBrandResponseTypedDict,
    )
    from .upsertunderwriting import (
        UpsertUnderwritingGlobals,
        UpsertUnderwritingGlobalsTypedDict,
        UpsertUnderwritingRequest,
        UpsertUnderwritingRequestTypedDict,
        UpsertUnderwritingResponse,
        UpsertUnderwritingResponseTypedDict,
    )

__all__ = [
    "AcceptDisputeGlobals",
    "AcceptDisputeGlobalsTypedDict",
    "AcceptDisputeRequest",
    "AcceptDisputeRequestTypedDict",
    "AcceptDisputeResponse",
    "AcceptDisputeResponseTypedDict",
    "AssignAccountCountriesGlobals",
    "AssignAccountCountriesGlobalsTypedDict",
    "AssignAccountCountriesRequest",
    "AssignAccountCountriesRequestTypedDict",
    "AssignAccountCountriesResponse",
    "AssignAccountCountriesResponseTypedDict",
    "CancelScheduleGlobals",
    "CancelScheduleGlobalsTypedDict",
    "CancelScheduleRequest",
    "CancelScheduleRequestTypedDict",
    "CancelScheduleResponse",
    "CancelScheduleResponseTypedDict",
    "CompleteBankAccountVerificationGlobals",
    "CompleteBankAccountVerificationGlobalsTypedDict",
    "CompleteBankAccountVerificationRequest",
    "CompleteBankAccountVerificationRequestTypedDict",
    "CompleteBankAccountVerificationResponse",
    "CompleteBankAccountVerificationResponseTypedDict",
    "CompleteMicroDepositsGlobals",
    "CompleteMicroDepositsGlobalsTypedDict",
    "CompleteMicroDepositsRequest",
    "CompleteMicroDepositsRequestTypedDict",
    "CompleteMicroDepositsResponse",
    "CompleteMicroDepositsResponseTypedDict",
    "ConnectAccountGlobals",
    "ConnectAccountGlobalsTypedDict",
    "ConnectAccountRequest",
    "ConnectAccountRequestTypedDict",
    "ConnectAccountResponse",
    "ConnectAccountResponseTypedDict",
    "CreateAccessTokenGlobals",
    "CreateAccessTokenGlobalsTypedDict",
    "CreateAccessTokenResponse",
    "CreateAccessTokenResponseTypedDict",
    "CreateAccountGlobals",
    "CreateAccountGlobalsTypedDict",
    "CreateAccountResponse",
    "CreateAccountResponseTypedDict",
    "CreateApplePaySessionGlobals",
    "CreateApplePaySessionGlobalsTypedDict",
    "CreateApplePaySessionRequest",
    "CreateApplePaySessionRequestTypedDict",
    "CreateApplePaySessionResponse",
    "CreateApplePaySessionResponseTypedDict",
    "CreateBrandGlobals",
    "CreateBrandGlobalsTypedDict",
    "CreateBrandRequest",
    "CreateBrandRequestTypedDict",
    "CreateBrandResponse",
    "CreateBrandResponseTypedDict",
    "CreateCancellationGlobals",
    "CreateCancellationGlobalsTypedDict",
    "CreateCancellationRequest",
    "CreateCancellationRequestTypedDict",
    "CreateCancellationResponse",
    "CreateCancellationResponseTypedDict",
    "CreateFeePlanAgreementsGlobals",
    "CreateFeePlanAgreementsGlobalsTypedDict",
    "CreateFeePlanAgreementsRequest",
    "CreateFeePlanAgreementsRequestTypedDict",
    "CreateFeePlanAgreementsResponse",
    "CreateFeePlanAgreementsResponseTypedDict",
    "CreateInvoiceGlobals",
    "CreateInvoiceGlobalsTypedDict",
    "CreateInvoicePaymentGlobals",
    "CreateInvoicePaymentGlobalsTypedDict",
    "CreateInvoicePaymentRequest",
    "CreateInvoicePaymentRequestTypedDict",
    "CreateInvoicePaymentResponse",
    "CreateInvoicePaymentResponseTypedDict",
    "CreateInvoiceRequest",
    "CreateInvoiceRequestTypedDict",
    "CreateInvoiceResponse",
    "CreateInvoiceResponseTypedDict",
    "CreateOnboardingInviteGlobals",
    "CreateOnboardingInviteGlobalsTypedDict",
    "CreateOnboardingInviteResponse",
    "CreateOnboardingInviteResponseTypedDict",
    "CreatePaymentLinkGlobals",
    "CreatePaymentLinkGlobalsTypedDict",
    "CreatePaymentLinkRequest",
    "CreatePaymentLinkRequestTypedDict",
    "CreatePaymentLinkResponse",
    "CreatePaymentLinkResponseTypedDict",
    "CreateProductGlobals",
    "CreateProductGlobalsTypedDict",
    "CreateProductRequest",
    "CreateProductRequestTypedDict",
    "CreateProductResponse",
    "CreateProductResponseTypedDict",
    "CreateReceiptsGlobals",
    "CreateReceiptsGlobalsTypedDict",
    "CreateReceiptsResponse",
    "CreateReceiptsResponseTypedDict",
    "CreateRepresentativeGlobals",
    "CreateRepresentativeGlobalsTypedDict",
    "CreateRepresentativeRequest",
    "CreateRepresentativeRequestTypedDict",
    "CreateRepresentativeResponse",
    "CreateRepresentativeResponseTypedDict",
    "CreateReversalGlobals",
    "CreateReversalGlobalsTypedDict",
    "CreateReversalRequest",
    "CreateReversalRequestTypedDict",
    "CreateReversalResponse",
    "CreateReversalResponseTypedDict",
    "CreateScheduleGlobals",
    "CreateScheduleGlobalsTypedDict",
    "CreateScheduleRequest",
    "CreateScheduleRequestTypedDict",
    "CreateScheduleResponse",
    "CreateScheduleResponseTypedDict",
    "CreateSweepConfigGlobals",
    "CreateSweepConfigGlobalsTypedDict",
    "CreateSweepConfigRequest",
    "CreateSweepConfigRequestTypedDict",
    "CreateSweepConfigResponse",
    "CreateSweepConfigResponseTypedDict",
    "CreateTerminalApplicationGlobals",
    "CreateTerminalApplicationGlobalsTypedDict",
    "CreateTerminalApplicationResponse",
    "CreateTerminalApplicationResponseTypedDict",
    "CreateTerminalApplicationVersionGlobals",
    "CreateTerminalApplicationVersionGlobalsTypedDict",
    "CreateTerminalApplicationVersionRequest",
    "CreateTerminalApplicationVersionRequestTypedDict",
    "CreateTerminalApplicationVersionResponse",
    "CreateTerminalApplicationVersionResponseTypedDict",
    "CreateTicketGlobals",
    "CreateTicketGlobalsTypedDict",
    "CreateTicketRequest",
    "CreateTicketRequestTypedDict",
    "CreateTicketResponse",
    "CreateTicketResponseTypedDict",
    "CreateTransferGlobals",
    "CreateTransferGlobalsTypedDict",
    "CreateTransferOptionsGlobals",
    "CreateTransferOptionsGlobalsTypedDict",
    "CreateTransferOptionsRequest",
    "CreateTransferOptionsRequestTypedDict",
    "CreateTransferOptionsResponse",
    "CreateTransferOptionsResponseTypedDict",
    "CreateTransferRequest",
    "CreateTransferRequestTypedDict",
    "CreateTransferResponse",
    "CreateTransferResponseResult",
    "CreateTransferResponseResultTypedDict",
    "CreateTransferResponseTypedDict",
    "CreateWalletGlobals",
    "CreateWalletGlobalsTypedDict",
    "CreateWalletRequest",
    "CreateWalletRequestTypedDict",
    "CreateWalletResponse",
    "CreateWalletResponseTypedDict",
    "CreateWebhookGlobals",
    "CreateWebhookGlobalsTypedDict",
    "CreateWebhookResponse",
    "CreateWebhookResponseTypedDict",
    "DeleteDisputeEvidenceFileGlobals",
    "DeleteDisputeEvidenceFileGlobalsTypedDict",
    "DeleteDisputeEvidenceFileRequest",
    "DeleteDisputeEvidenceFileRequestTypedDict",
    "DeleteDisputeEvidenceFileResponse",
    "DeleteDisputeEvidenceFileResponseTypedDict",
    "DeleteImageGlobals",
    "DeleteImageGlobalsTypedDict",
    "DeleteImageRequest",
    "DeleteImageRequestTypedDict",
    "DeleteImageResponse",
    "DeleteImageResponseTypedDict",
    "DeleteInvoiceGlobals",
    "DeleteInvoiceGlobalsTypedDict",
    "DeleteInvoiceRequest",
    "DeleteInvoiceRequestTypedDict",
    "DeleteInvoiceResponse",
    "DeleteInvoiceResponseTypedDict",
    "DeleteRepresentativeGlobals",
    "DeleteRepresentativeGlobalsTypedDict",
    "DeleteRepresentativeRequest",
    "DeleteRepresentativeRequestTypedDict",
    "DeleteRepresentativeResponse",
    "DeleteRepresentativeResponseTypedDict",
    "DeleteTerminalApplicationGlobals",
    "DeleteTerminalApplicationGlobalsTypedDict",
    "DeleteTerminalApplicationRequest",
    "DeleteTerminalApplicationRequestTypedDict",
    "DeleteTerminalApplicationResponse",
    "DeleteTerminalApplicationResponseTypedDict",
    "DisableBankAccountGlobals",
    "DisableBankAccountGlobalsTypedDict",
    "DisableBankAccountRequest",
    "DisableBankAccountRequestTypedDict",
    "DisableBankAccountResponse",
    "DisableBankAccountResponseTypedDict",
    "DisableCapabilityGlobals",
    "DisableCapabilityGlobalsTypedDict",
    "DisableCapabilityRequest",
    "DisableCapabilityRequestTypedDict",
    "DisableCapabilityResponse",
    "DisableCapabilityResponseTypedDict",
    "DisableCardGlobals",
    "DisableCardGlobalsTypedDict",
    "DisableCardRequest",
    "DisableCardRequestTypedDict",
    "DisableCardResponse",
    "DisableCardResponseTypedDict",
    "DisablePaymentLinkGlobals",
    "DisablePaymentLinkGlobalsTypedDict",
    "DisablePaymentLinkRequest",
    "DisablePaymentLinkRequestTypedDict",
    "DisablePaymentLinkResponse",
    "DisablePaymentLinkResponseTypedDict",
    "DisableProductGlobals",
    "DisableProductGlobalsTypedDict",
    "DisableProductRequest",
    "DisableProductRequestTypedDict",
    "DisableProductResponse",
    "DisableProductResponseTypedDict",
    "DisableWebhookGlobals",
    "DisableWebhookGlobalsTypedDict",
    "DisableWebhookRequest",
    "DisableWebhookRequestTypedDict",
    "DisableWebhookResponse",
    "DisableWebhookResponseTypedDict",
    "DisconnectAccountGlobals",
    "DisconnectAccountGlobalsTypedDict",
    "DisconnectAccountRequest",
    "DisconnectAccountRequestTypedDict",
    "DisconnectAccountResponse",
    "DisconnectAccountResponseTypedDict",
    "GenerateEndToEndKeyGlobals",
    "GenerateEndToEndKeyGlobalsTypedDict",
    "GenerateEndToEndKeyRequest",
    "GenerateEndToEndKeyRequestTypedDict",
    "GenerateEndToEndKeyResponse",
    "GenerateEndToEndKeyResponseTypedDict",
    "GetAccountCountriesGlobals",
    "GetAccountCountriesGlobalsTypedDict",
    "GetAccountCountriesRequest",
    "GetAccountCountriesRequestTypedDict",
    "GetAccountCountriesResponse",
    "GetAccountCountriesResponseTypedDict",
    "GetAccountGlobals",
    "GetAccountGlobalsTypedDict",
    "GetAccountRequest",
    "GetAccountRequestTypedDict",
    "GetAccountResponse",
    "GetAccountResponseTypedDict",
    "GetAccountTerminalApplicationGlobals",
    "GetAccountTerminalApplicationGlobalsTypedDict",
    "GetAccountTerminalApplicationRequest",
    "GetAccountTerminalApplicationRequestTypedDict",
    "GetAccountTerminalApplicationResponse",
    "GetAccountTerminalApplicationResponseTypedDict",
    "GetAdjustmentGlobals",
    "GetAdjustmentGlobalsTypedDict",
    "GetAdjustmentRequest",
    "GetAdjustmentRequestTypedDict",
    "GetAdjustmentResponse",
    "GetAdjustmentResponseTypedDict",
    "GetApplePayMerchantDomainsGlobals",
    "GetApplePayMerchantDomainsGlobalsTypedDict",
    "GetApplePayMerchantDomainsRequest",
    "GetApplePayMerchantDomainsRequestTypedDict",
    "GetApplePayMerchantDomainsResponse",
    "GetApplePayMerchantDomainsResponseTypedDict",
    "GetAvatarGlobals",
    "GetAvatarGlobalsTypedDict",
    "GetAvatarRequest",
    "GetAvatarRequestTypedDict",
    "GetAvatarResponse",
    "GetAvatarResponseTypedDict",
    "GetBankAccountGlobals",
    "GetBankAccountGlobalsTypedDict",
    "GetBankAccountRequest",
    "GetBankAccountRequestTypedDict",
    "GetBankAccountResponse",
    "GetBankAccountResponseTypedDict",
    "GetBankAccountVerificationGlobals",
    "GetBankAccountVerificationGlobalsTypedDict",
    "GetBankAccountVerificationRequest",
    "GetBankAccountVerificationRequestTypedDict",
    "GetBankAccountVerificationResponse",
    "GetBankAccountVerificationResponseTypedDict",
    "GetBrandGlobals",
    "GetBrandGlobalsTypedDict",
    "GetBrandRequest",
    "GetBrandRequestTypedDict",
    "GetBrandResponse",
    "GetBrandResponseTypedDict",
    "GetCancellationGlobals",
    "GetCancellationGlobalsTypedDict",
    "GetCancellationRequest",
    "GetCancellationRequestTypedDict",
    "GetCancellationResponse",
    "GetCancellationResponseTypedDict",
    "GetCapabilityGlobals",
    "GetCapabilityGlobalsTypedDict",
    "GetCapabilityRequest",
    "GetCapabilityRequestTypedDict",
    "GetCapabilityResponse",
    "GetCapabilityResponseTypedDict",
    "GetCardGlobals",
    "GetCardGlobalsTypedDict",
    "GetCardRequest",
    "GetCardRequestTypedDict",
    "GetCardResponse",
    "GetCardResponseTypedDict",
    "GetDisputeEvidenceDataGlobals",
    "GetDisputeEvidenceDataGlobalsTypedDict",
    "GetDisputeEvidenceDataRequest",
    "GetDisputeEvidenceDataRequestTypedDict",
    "GetDisputeEvidenceDataResponse",
    "GetDisputeEvidenceDataResponseResult",
    "GetDisputeEvidenceDataResponseResultTypedDict",
    "GetDisputeEvidenceDataResponseTypedDict",
    "GetDisputeEvidenceGlobals",
    "GetDisputeEvidenceGlobalsTypedDict",
    "GetDisputeEvidenceRequest",
    "GetDisputeEvidenceRequestTypedDict",
    "GetDisputeEvidenceResponse",
    "GetDisputeEvidenceResponseTypedDict",
    "GetDisputeGlobals",
    "GetDisputeGlobalsTypedDict",
    "GetDisputeRequest",
    "GetDisputeRequestTypedDict",
    "GetDisputeResponse",
    "GetDisputeResponseTypedDict",
    "GetEnrichmentAddressGlobals",
    "GetEnrichmentAddressGlobalsTypedDict",
    "GetEnrichmentAddressRequest",
    "GetEnrichmentAddressRequestTypedDict",
    "GetEnrichmentAddressResponse",
    "GetEnrichmentAddressResponseTypedDict",
    "GetEnrichmentProfileGlobals",
    "GetEnrichmentProfileGlobalsTypedDict",
    "GetEnrichmentProfileRequest",
    "GetEnrichmentProfileRequestTypedDict",
    "GetEnrichmentProfileResponse",
    "GetEnrichmentProfileResponseTypedDict",
    "GetFileDetailsGlobals",
    "GetFileDetailsGlobalsTypedDict",
    "GetFileDetailsRequest",
    "GetFileDetailsRequestTypedDict",
    "GetFileDetailsResponse",
    "GetFileDetailsResponseTypedDict",
    "GetFullIssuedCardGlobals",
    "GetFullIssuedCardGlobalsTypedDict",
    "GetFullIssuedCardRequest",
    "GetFullIssuedCardRequestTypedDict",
    "GetFullIssuedCardResponse",
    "GetFullIssuedCardResponseTypedDict",
    "GetImageMetadataGlobals",
    "GetImageMetadataGlobalsTypedDict",
    "GetImageMetadataRequest",
    "GetImageMetadataRequestTypedDict",
    "GetImageMetadataResponse",
    "GetImageMetadataResponseTypedDict",
    "GetInvoiceGlobals",
    "GetInvoiceGlobalsTypedDict",
    "GetInvoiceRequest",
    "GetInvoiceRequestTypedDict",
    "GetInvoiceResponse",
    "GetInvoiceResponseTypedDict",
    "GetIssuedCardAuthorizationGlobals",
    "GetIssuedCardAuthorizationGlobalsTypedDict",
    "GetIssuedCardAuthorizationRequest",
    "GetIssuedCardAuthorizationRequestTypedDict",
    "GetIssuedCardAuthorizationResponse",
    "GetIssuedCardAuthorizationResponseTypedDict",
    "GetIssuedCardGlobals",
    "GetIssuedCardGlobalsTypedDict",
    "GetIssuedCardRequest",
    "GetIssuedCardRequestTypedDict",
    "GetIssuedCardResponse",
    "GetIssuedCardResponseTypedDict",
    "GetIssuedCardTransactionGlobals",
    "GetIssuedCardTransactionGlobalsTypedDict",
    "GetIssuedCardTransactionRequest",
    "GetIssuedCardTransactionRequestTypedDict",
    "GetIssuedCardTransactionResponse",
    "GetIssuedCardTransactionResponseTypedDict",
    "GetMerchantProcessingAgreementGlobals",
    "GetMerchantProcessingAgreementGlobalsTypedDict",
    "GetMerchantProcessingAgreementRequest",
    "GetMerchantProcessingAgreementRequestTypedDict",
    "GetMerchantProcessingAgreementResponse",
    "GetMerchantProcessingAgreementResponseTypedDict",
    "GetOnboardingInviteGlobals",
    "GetOnboardingInviteGlobalsTypedDict",
    "GetOnboardingInviteRequest",
    "GetOnboardingInviteRequestTypedDict",
    "GetOnboardingInviteResponse",
    "GetOnboardingInviteResponseTypedDict",
    "GetPaymentLinkGlobals",
    "GetPaymentLinkGlobalsTypedDict",
    "GetPaymentLinkQRCodeGlobals",
    "GetPaymentLinkQRCodeGlobalsTypedDict",
    "GetPaymentLinkQRCodeRequest",
    "GetPaymentLinkQRCodeRequestTypedDict",
    "GetPaymentLinkQRCodeResponse",
    "GetPaymentLinkQRCodeResponseResult",
    "GetPaymentLinkQRCodeResponseResultTypedDict",
    "GetPaymentLinkQRCodeResponseTypedDict",
    "GetPaymentLinkRequest",
    "GetPaymentLinkRequestTypedDict",
    "GetPaymentLinkResponse",
    "GetPaymentLinkResponseTypedDict",
    "GetPaymentMethodGlobals",
    "GetPaymentMethodGlobalsTypedDict",
    "GetPaymentMethodRequest",
    "GetPaymentMethodRequestTypedDict",
    "GetPaymentMethodResponse",
    "GetPaymentMethodResponseTypedDict",
    "GetProductGlobals",
    "GetProductGlobalsTypedDict",
    "GetProductRequest",
    "GetProductRequestTypedDict",
    "GetProductResponse",
    "GetProductResponseTypedDict",
    "GetPublicImageRequest",
    "GetPublicImageRequestTypedDict",
    "GetPublicImageResponse",
    "GetPublicImageResponseResult",
    "GetPublicImageResponseResultTypedDict",
    "GetPublicImageResponseTypedDict",
    "GetRefundGlobals",
    "GetRefundGlobalsTypedDict",
    "GetRefundRequest",
    "GetRefundRequestTypedDict",
    "GetRefundResponse",
    "GetRefundResponseTypedDict",
    "GetRepresentativeGlobals",
    "GetRepresentativeGlobalsTypedDict",
    "GetRepresentativeRequest",
    "GetRepresentativeRequestTypedDict",
    "GetRepresentativeResponse",
    "GetRepresentativeResponseTypedDict",
    "GetResidualGlobals",
    "GetResidualGlobalsTypedDict",
    "GetResidualRequest",
    "GetResidualRequestTypedDict",
    "GetResidualResponse",
    "GetResidualResponseTypedDict",
    "GetScheduledOccurrenceGlobals",
    "GetScheduledOccurrenceGlobalsTypedDict",
    "GetScheduledOccurrenceRequest",
    "GetScheduledOccurrenceRequestTypedDict",
    "GetScheduledOccurrenceResponse",
    "GetScheduledOccurrenceResponseTypedDict",
    "GetSchedulesGlobals",
    "GetSchedulesGlobalsTypedDict",
    "GetSchedulesRequest",
    "GetSchedulesRequestTypedDict",
    "GetSchedulesResponse",
    "GetSchedulesResponseTypedDict",
    "GetStatementGlobals",
    "GetStatementGlobalsTypedDict",
    "GetStatementRequest",
    "GetStatementRequestTypedDict",
    "GetStatementResponse",
    "GetStatementResponseResult",
    "GetStatementResponseResultTypedDict",
    "GetStatementResponseTypedDict",
    "GetSweepConfigGlobals",
    "GetSweepConfigGlobalsTypedDict",
    "GetSweepConfigRequest",
    "GetSweepConfigRequestTypedDict",
    "GetSweepConfigResponse",
    "GetSweepConfigResponseTypedDict",
    "GetSweepGlobals",
    "GetSweepGlobalsTypedDict",
    "GetSweepRequest",
    "GetSweepRequestTypedDict",
    "GetSweepResponse",
    "GetSweepResponseTypedDict",
    "GetTerminalApplicationGlobals",
    "GetTerminalApplicationGlobalsTypedDict",
    "GetTerminalApplicationRequest",
    "GetTerminalApplicationRequestTypedDict",
    "GetTerminalApplicationResponse",
    "GetTerminalApplicationResponseTypedDict",
    "GetTerminalConfigurationGlobals",
    "GetTerminalConfigurationGlobalsTypedDict",
    "GetTerminalConfigurationRequest",
    "GetTerminalConfigurationRequestTypedDict",
    "GetTerminalConfigurationResponse",
    "GetTerminalConfigurationResponseTypedDict",
    "GetTermsOfServiceTokenGlobals",
    "GetTermsOfServiceTokenGlobalsTypedDict",
    "GetTermsOfServiceTokenRequest",
    "GetTermsOfServiceTokenRequestTypedDict",
    "GetTermsOfServiceTokenResponse",
    "GetTermsOfServiceTokenResponseTypedDict",
    "GetTicketGlobals",
    "GetTicketGlobalsTypedDict",
    "GetTicketRequest",
    "GetTicketRequestTypedDict",
    "GetTicketResponse",
    "GetTicketResponseTypedDict",
    "GetTransferGlobals",
    "GetTransferGlobalsTypedDict",
    "GetTransferRequest",
    "GetTransferRequestTypedDict",
    "GetTransferResponse",
    "GetTransferResponseTypedDict",
    "GetUnderwritingGlobals",
    "GetUnderwritingGlobalsTypedDict",
    "GetUnderwritingRequest",
    "GetUnderwritingRequestTypedDict",
    "GetUnderwritingResponse",
    "GetUnderwritingResponseTypedDict",
    "GetWalletGlobals",
    "GetWalletGlobalsTypedDict",
    "GetWalletRequest",
    "GetWalletRequestTypedDict",
    "GetWalletResponse",
    "GetWalletResponseTypedDict",
    "GetWalletTransactionGlobals",
    "GetWalletTransactionGlobalsTypedDict",
    "GetWalletTransactionRequest",
    "GetWalletTransactionRequestTypedDict",
    "GetWalletTransactionResponse",
    "GetWalletTransactionResponseTypedDict",
    "GetWebhookGlobals",
    "GetWebhookGlobalsTypedDict",
    "GetWebhookRequest",
    "GetWebhookRequestTypedDict",
    "GetWebhookResponse",
    "GetWebhookResponseTypedDict",
    "GetWebhookSecretGlobals",
    "GetWebhookSecretGlobalsTypedDict",
    "GetWebhookSecretRequest",
    "GetWebhookSecretRequestTypedDict",
    "GetWebhookSecretResponse",
    "GetWebhookSecretResponseTypedDict",
    "Hydrate",
    "InitiateBankAccountVerificationGlobals",
    "InitiateBankAccountVerificationGlobalsTypedDict",
    "InitiateBankAccountVerificationRequest",
    "InitiateBankAccountVerificationRequestTypedDict",
    "InitiateBankAccountVerificationResponse",
    "InitiateBankAccountVerificationResponseTypedDict",
    "InitiateMicroDepositsGlobals",
    "InitiateMicroDepositsGlobalsTypedDict",
    "InitiateMicroDepositsRequest",
    "InitiateMicroDepositsRequestTypedDict",
    "InitiateMicroDepositsResponse",
    "InitiateMicroDepositsResponseTypedDict",
    "InitiateRefundGlobals",
    "InitiateRefundGlobalsTypedDict",
    "InitiateRefundRequest",
    "InitiateRefundRequestTypedDict",
    "InitiateRefundResponse",
    "InitiateRefundResponseResult",
    "InitiateRefundResponseResultTypedDict",
    "InitiateRefundResponseTypedDict",
    "LinkAccountTerminalApplicationGlobals",
    "LinkAccountTerminalApplicationGlobalsTypedDict",
    "LinkAccountTerminalApplicationRequest",
    "LinkAccountTerminalApplicationRequestTypedDict",
    "LinkAccountTerminalApplicationResponse",
    "LinkAccountTerminalApplicationResponseTypedDict",
    "LinkApplePayTokenGlobals",
    "LinkApplePayTokenGlobalsTypedDict",
    "LinkApplePayTokenRequest",
    "LinkApplePayTokenRequestTypedDict",
    "LinkApplePayTokenResponse",
    "LinkApplePayTokenResponseTypedDict",
    "LinkBankAccountGlobals",
    "LinkBankAccountGlobalsTypedDict",
    "LinkBankAccountRequest",
    "LinkBankAccountRequestTypedDict",
    "LinkBankAccountResponse",
    "LinkBankAccountResponseTypedDict",
    "LinkCardGlobals",
    "LinkCardGlobalsTypedDict",
    "LinkCardRequest",
    "LinkCardRequestTypedDict",
    "LinkCardResponse",
    "LinkCardResponseTypedDict",
    "ListAccountTerminalApplicationsGlobals",
    "ListAccountTerminalApplicationsGlobalsTypedDict",
    "ListAccountTerminalApplicationsRequest",
    "ListAccountTerminalApplicationsRequestTypedDict",
    "ListAccountTerminalApplicationsResponse",
    "ListAccountTerminalApplicationsResponseTypedDict",
    "ListAccountsGlobals",
    "ListAccountsGlobalsTypedDict",
    "ListAccountsRequest",
    "ListAccountsRequestTypedDict",
    "ListAccountsResponse",
    "ListAccountsResponseTypedDict",
    "ListAdjustmentsGlobals",
    "ListAdjustmentsGlobalsTypedDict",
    "ListAdjustmentsRequest",
    "ListAdjustmentsRequestTypedDict",
    "ListAdjustmentsResponse",
    "ListAdjustmentsResponseTypedDict",
    "ListBankAccountsGlobals",
    "ListBankAccountsGlobalsTypedDict",
    "ListBankAccountsRequest",
    "ListBankAccountsRequestTypedDict",
    "ListBankAccountsResponse",
    "ListBankAccountsResponseTypedDict",
    "ListCapabilitiesGlobals",
    "ListCapabilitiesGlobalsTypedDict",
    "ListCapabilitiesRequest",
    "ListCapabilitiesRequestTypedDict",
    "ListCapabilitiesResponse",
    "ListCapabilitiesResponseTypedDict",
    "ListCardsGlobals",
    "ListCardsGlobalsTypedDict",
    "ListCardsRequest",
    "ListCardsRequestTypedDict",
    "ListCardsResponse",
    "ListCardsResponseTypedDict",
    "ListConnectedAccountsForAccountGlobals",
    "ListConnectedAccountsForAccountGlobalsTypedDict",
    "ListConnectedAccountsForAccountRequest",
    "ListConnectedAccountsForAccountRequestTypedDict",
    "ListConnectedAccountsForAccountResponse",
    "ListConnectedAccountsForAccountResponseTypedDict",
    "ListDisputeEvidenceGlobals",
    "ListDisputeEvidenceGlobalsTypedDict",
    "ListDisputeEvidenceRequest",
    "ListDisputeEvidenceRequestTypedDict",
    "ListDisputeEvidenceResponse",
    "ListDisputeEvidenceResponseTypedDict",
    "ListDisputesGlobals",
    "ListDisputesGlobalsTypedDict",
    "ListDisputesRequest",
    "ListDisputesRequestTypedDict",
    "ListDisputesResponse",
    "ListDisputesResponseTypedDict",
    "ListEventTypesGlobals",
    "ListEventTypesGlobalsTypedDict",
    "ListEventTypesRequest",
    "ListEventTypesRequestTypedDict",
    "ListEventTypesResponse",
    "ListEventTypesResponseTypedDict",
    "ListFeePlanAgreementsGlobals",
    "ListFeePlanAgreementsGlobalsTypedDict",
    "ListFeePlanAgreementsRequest",
    "ListFeePlanAgreementsRequestTypedDict",
    "ListFeePlanAgreementsResponse",
    "ListFeePlanAgreementsResponseTypedDict",
    "ListFeePlansGlobals",
    "ListFeePlansGlobalsTypedDict",
    "ListFeePlansRequest",
    "ListFeePlansRequestTypedDict",
    "ListFeePlansResponse",
    "ListFeePlansResponseTypedDict",
    "ListFeeRevenueGlobals",
    "ListFeeRevenueGlobalsTypedDict",
    "ListFeeRevenueRequest",
    "ListFeeRevenueRequestTypedDict",
    "ListFeeRevenueResponse",
    "ListFeeRevenueResponseTypedDict",
    "ListFeesFetchGlobals",
    "ListFeesFetchGlobalsTypedDict",
    "ListFeesFetchRequest",
    "ListFeesFetchRequestTypedDict",
    "ListFeesFetchResponse",
    "ListFeesFetchResponseTypedDict",
    "ListFilesGlobals",
    "ListFilesGlobalsTypedDict",
    "ListFilesRequest",
    "ListFilesRequestTypedDict",
    "ListFilesResponse",
    "ListFilesResponseTypedDict",
    "ListImageMetadataGlobals",
    "ListImageMetadataGlobalsTypedDict",
    "ListImageMetadataRequest",
    "ListImageMetadataRequestTypedDict",
    "ListImageMetadataResponse",
    "ListImageMetadataResponseTypedDict",
    "ListIndustriesGlobals",
    "ListIndustriesGlobalsTypedDict",
    "ListIndustriesRequest",
    "ListIndustriesRequestTypedDict",
    "ListIndustriesResponse",
    "ListIndustriesResponseTypedDict",
    "ListInstitutionsGlobals",
    "ListInstitutionsGlobalsTypedDict",
    "ListInstitutionsRequest",
    "ListInstitutionsRequestTypedDict",
    "ListInstitutionsResponse",
    "ListInstitutionsResponseTypedDict",
    "ListInvoicePaymentsGlobals",
    "ListInvoicePaymentsGlobalsTypedDict",
    "ListInvoicePaymentsRequest",
    "ListInvoicePaymentsRequestTypedDict",
    "ListInvoicePaymentsResponse",
    "ListInvoicePaymentsResponseTypedDict",
    "ListInvoicesGlobals",
    "ListInvoicesGlobalsTypedDict",
    "ListInvoicesRequest",
    "ListInvoicesRequestTypedDict",
    "ListInvoicesResponse",
    "ListInvoicesResponseTypedDict",
    "ListIssuedCardAuthorizationEventsGlobals",
    "ListIssuedCardAuthorizationEventsGlobalsTypedDict",
    "ListIssuedCardAuthorizationEventsRequest",
    "ListIssuedCardAuthorizationEventsRequestTypedDict",
    "ListIssuedCardAuthorizationEventsResponse",
    "ListIssuedCardAuthorizationEventsResponseTypedDict",
    "ListIssuedCardAuthorizationsGlobals",
    "ListIssuedCardAuthorizationsGlobalsTypedDict",
    "ListIssuedCardAuthorizationsRequest",
    "ListIssuedCardAuthorizationsRequestTypedDict",
    "ListIssuedCardAuthorizationsResponse",
    "ListIssuedCardAuthorizationsResponseTypedDict",
    "ListIssuedCardTransactionsGlobals",
    "ListIssuedCardTransactionsGlobalsTypedDict",
    "ListIssuedCardTransactionsRequest",
    "ListIssuedCardTransactionsRequestTypedDict",
    "ListIssuedCardTransactionsResponse",
    "ListIssuedCardTransactionsResponseTypedDict",
    "ListIssuedCardsGlobals",
    "ListIssuedCardsGlobalsTypedDict",
    "ListIssuedCardsRequest",
    "ListIssuedCardsRequestTypedDict",
    "ListIssuedCardsResponse",
    "ListIssuedCardsResponseTypedDict",
    "ListOnboardingInvitesGlobals",
    "ListOnboardingInvitesGlobalsTypedDict",
    "ListOnboardingInvitesRequest",
    "ListOnboardingInvitesRequestTypedDict",
    "ListOnboardingInvitesResponse",
    "ListOnboardingInvitesResponseTypedDict",
    "ListPartnerPricingAgreementsGlobals",
    "ListPartnerPricingAgreementsGlobalsTypedDict",
    "ListPartnerPricingAgreementsRequest",
    "ListPartnerPricingAgreementsRequestTypedDict",
    "ListPartnerPricingAgreementsResponse",
    "ListPartnerPricingAgreementsResponseTypedDict",
    "ListPaymentLinksGlobals",
    "ListPaymentLinksGlobalsTypedDict",
    "ListPaymentLinksRequest",
    "ListPaymentLinksRequestTypedDict",
    "ListPaymentLinksResponse",
    "ListPaymentLinksResponseTypedDict",
    "ListPaymentMethodsGlobals",
    "ListPaymentMethodsGlobalsTypedDict",
    "ListPaymentMethodsRequest",
    "ListPaymentMethodsRequestTypedDict",
    "ListPaymentMethodsResponse",
    "ListPaymentMethodsResponseTypedDict",
    "ListProductsGlobals",
    "ListProductsGlobalsTypedDict",
    "ListProductsRequest",
    "ListProductsRequestTypedDict",
    "ListProductsResponse",
    "ListProductsResponseTypedDict",
    "ListReceiptsGlobals",
    "ListReceiptsGlobalsTypedDict",
    "ListReceiptsRequest",
    "ListReceiptsRequestTypedDict",
    "ListReceiptsResponse",
    "ListReceiptsResponseTypedDict",
    "ListRefundsGlobals",
    "ListRefundsGlobalsTypedDict",
    "ListRefundsRequest",
    "ListRefundsRequestTypedDict",
    "ListRefundsResponse",
    "ListRefundsResponseTypedDict",
    "ListRepresentativesGlobals",
    "ListRepresentativesGlobalsTypedDict",
    "ListRepresentativesRequest",
    "ListRepresentativesRequestTypedDict",
    "ListRepresentativesResponse",
    "ListRepresentativesResponseTypedDict",
    "ListResidualFeesGlobals",
    "ListResidualFeesGlobalsTypedDict",
    "ListResidualFeesRequest",
    "ListResidualFeesRequestTypedDict",
    "ListResidualFeesResponse",
    "ListResidualFeesResponseTypedDict",
    "ListResidualsGlobals",
    "ListResidualsGlobalsTypedDict",
    "ListResidualsRequest",
    "ListResidualsRequestTypedDict",
    "ListResidualsResponse",
    "ListResidualsResponseTypedDict",
    "ListSchedulesGlobals",
    "ListSchedulesGlobalsTypedDict",
    "ListSchedulesRequest",
    "ListSchedulesRequestTypedDict",
    "ListSchedulesResponse",
    "ListSchedulesResponseTypedDict",
    "ListStatementsGlobals",
    "ListStatementsGlobalsTypedDict",
    "ListStatementsRequest",
    "ListStatementsRequestTypedDict",
    "ListStatementsResponse",
    "ListStatementsResponseTypedDict",
    "ListSweepConfigsGlobals",
    "ListSweepConfigsGlobalsTypedDict",
    "ListSweepConfigsRequest",
    "ListSweepConfigsRequestTypedDict",
    "ListSweepConfigsResponse",
    "ListSweepConfigsResponseTypedDict",
    "ListSweepsGlobals",
    "ListSweepsGlobalsTypedDict",
    "ListSweepsRequest",
    "ListSweepsRequestTypedDict",
    "ListSweepsResponse",
    "ListSweepsResponseTypedDict",
    "ListTerminalApplicationsGlobals",
    "ListTerminalApplicationsGlobalsTypedDict",
    "ListTerminalApplicationsRequest",
    "ListTerminalApplicationsRequestTypedDict",
    "ListTerminalApplicationsResponse",
    "ListTerminalApplicationsResponseTypedDict",
    "ListTicketMessagesGlobals",
    "ListTicketMessagesGlobalsTypedDict",
    "ListTicketMessagesRequest",
    "ListTicketMessagesRequestTypedDict",
    "ListTicketMessagesResponse",
    "ListTicketMessagesResponseTypedDict",
    "ListTicketsGlobals",
    "ListTicketsGlobalsTypedDict",
    "ListTicketsRequest",
    "ListTicketsRequestTypedDict",
    "ListTicketsResponse",
    "ListTicketsResponseBody",
    "ListTicketsResponseBodyTypedDict",
    "ListTicketsResponseTypedDict",
    "ListTransfersGlobals",
    "ListTransfersGlobalsTypedDict",
    "ListTransfersRequest",
    "ListTransfersRequestTypedDict",
    "ListTransfersResponse",
    "ListTransfersResponseTypedDict",
    "ListWalletTransactionsGlobals",
    "ListWalletTransactionsGlobalsTypedDict",
    "ListWalletTransactionsRequest",
    "ListWalletTransactionsRequestTypedDict",
    "ListWalletTransactionsResponse",
    "ListWalletTransactionsResponseTypedDict",
    "ListWalletsGlobals",
    "ListWalletsGlobalsTypedDict",
    "ListWalletsRequest",
    "ListWalletsRequestTypedDict",
    "ListWalletsResponse",
    "ListWalletsResponseTypedDict",
    "ListWebhooksGlobals",
    "ListWebhooksGlobalsTypedDict",
    "ListWebhooksRequest",
    "ListWebhooksRequestTypedDict",
    "ListWebhooksResponse",
    "ListWebhooksResponseTypedDict",
    "PingGlobals",
    "PingGlobalsTypedDict",
    "PingRequest",
    "PingRequestTypedDict",
    "PingResponse",
    "PingResponseTypedDict",
    "PingWebhookGlobals",
    "PingWebhookGlobalsTypedDict",
    "PingWebhookRequest",
    "PingWebhookRequestTypedDict",
    "PingWebhookResponse",
    "PingWebhookResponseTypedDict",
    "RegisterApplePayMerchantDomainsGlobals",
    "RegisterApplePayMerchantDomainsGlobalsTypedDict",
    "RegisterApplePayMerchantDomainsRequest",
    "RegisterApplePayMerchantDomainsRequestTypedDict",
    "RegisterApplePayMerchantDomainsResponse",
    "RegisterApplePayMerchantDomainsResponseTypedDict",
    "RequestCapabilitiesGlobals",
    "RequestCapabilitiesGlobalsTypedDict",
    "RequestCapabilitiesRequest",
    "RequestCapabilitiesRequestTypedDict",
    "RequestCapabilitiesResponse",
    "RequestCapabilitiesResponseTypedDict",
    "RequestCardGlobals",
    "RequestCardGlobalsTypedDict",
    "RequestCardRequest",
    "RequestCardRequestTypedDict",
    "RequestCardResponse",
    "RequestCardResponseTypedDict",
    "RetrieveFeesGlobals",
    "RetrieveFeesGlobalsTypedDict",
    "RetrieveFeesRequest",
    "RetrieveFeesRequestTypedDict",
    "RetrieveFeesResponse",
    "RetrieveFeesResponseTypedDict",
    "RevokeAccessTokenGlobals",
    "RevokeAccessTokenGlobalsTypedDict",
    "RevokeAccessTokenResponse",
    "RevokeAccessTokenResponseTypedDict",
    "RevokeOnboardingInviteGlobals",
    "RevokeOnboardingInviteGlobalsTypedDict",
    "RevokeOnboardingInviteRequest",
    "RevokeOnboardingInviteRequestTypedDict",
    "RevokeOnboardingInviteResponse",
    "RevokeOnboardingInviteResponseTypedDict",
    "SaveUnderwritingGlobals",
    "SaveUnderwritingGlobalsTypedDict",
    "SaveUnderwritingRequest",
    "SaveUnderwritingRequestTypedDict",
    "SaveUnderwritingResponse",
    "SaveUnderwritingResponseTypedDict",
    "SearchInstitutionsGlobals",
    "SearchInstitutionsGlobalsTypedDict",
    "SearchInstitutionsRequest",
    "SearchInstitutionsRequestTypedDict",
    "SearchInstitutionsResponse",
    "SearchInstitutionsResponseTypedDict",
    "SubmitDisputeEvidenceGlobals",
    "SubmitDisputeEvidenceGlobalsTypedDict",
    "SubmitDisputeEvidenceRequest",
    "SubmitDisputeEvidenceRequestTypedDict",
    "SubmitDisputeEvidenceResponse",
    "SubmitDisputeEvidenceResponseTypedDict",
    "TestEndToEndTokenGlobals",
    "TestEndToEndTokenGlobalsTypedDict",
    "TestEndToEndTokenResponse",
    "TestEndToEndTokenResponseTypedDict",
    "UpdateAccountGlobals",
    "UpdateAccountGlobalsTypedDict",
    "UpdateAccountRequest",
    "UpdateAccountRequestTypedDict",
    "UpdateAccountResponse",
    "UpdateAccountResponseTypedDict",
    "UpdateApplePayMerchantDomainsGlobals",
    "UpdateApplePayMerchantDomainsGlobalsTypedDict",
    "UpdateApplePayMerchantDomainsRequest",
    "UpdateApplePayMerchantDomainsRequestTypedDict",
    "UpdateApplePayMerchantDomainsResponse",
    "UpdateApplePayMerchantDomainsResponseTypedDict",
    "UpdateCardGlobals",
    "UpdateCardGlobalsTypedDict",
    "UpdateCardRequest",
    "UpdateCardRequestTypedDict",
    "UpdateCardResponse",
    "UpdateCardResponseTypedDict",
    "UpdateDisputeEvidenceGlobals",
    "UpdateDisputeEvidenceGlobalsTypedDict",
    "UpdateDisputeEvidenceRequest",
    "UpdateDisputeEvidenceRequestTypedDict",
    "UpdateDisputeEvidenceResponse",
    "UpdateDisputeEvidenceResponseTypedDict",
    "UpdateImageGlobals",
    "UpdateImageGlobalsTypedDict",
    "UpdateImageMetadataGlobals",
    "UpdateImageMetadataGlobalsTypedDict",
    "UpdateImageMetadataRequest",
    "UpdateImageMetadataRequestTypedDict",
    "UpdateImageMetadataResponse",
    "UpdateImageMetadataResponseTypedDict",
    "UpdateImageRequest",
    "UpdateImageRequestTypedDict",
    "UpdateImageResponse",
    "UpdateImageResponseTypedDict",
    "UpdateInvoiceGlobals",
    "UpdateInvoiceGlobalsTypedDict",
    "UpdateInvoiceRequest",
    "UpdateInvoiceRequestTypedDict",
    "UpdateInvoiceResponse",
    "UpdateInvoiceResponseTypedDict",
    "UpdateIssuedCardGlobals",
    "UpdateIssuedCardGlobalsTypedDict",
    "UpdateIssuedCardRequest",
    "UpdateIssuedCardRequestTypedDict",
    "UpdateIssuedCardResponse",
    "UpdateIssuedCardResponseTypedDict",
    "UpdatePaymentLinkGlobals",
    "UpdatePaymentLinkGlobalsTypedDict",
    "UpdatePaymentLinkRequest",
    "UpdatePaymentLinkRequestTypedDict",
    "UpdatePaymentLinkResponse",
    "UpdatePaymentLinkResponseTypedDict",
    "UpdateProductGlobals",
    "UpdateProductGlobalsTypedDict",
    "UpdateProductRequest",
    "UpdateProductRequestTypedDict",
    "UpdateProductResponse",
    "UpdateProductResponseTypedDict",
    "UpdateRepresentativeGlobals",
    "UpdateRepresentativeGlobalsTypedDict",
    "UpdateRepresentativeRequest",
    "UpdateRepresentativeRequestTypedDict",
    "UpdateRepresentativeResponse",
    "UpdateRepresentativeResponseTypedDict",
    "UpdateScheduleGlobals",
    "UpdateScheduleGlobalsTypedDict",
    "UpdateScheduleRequest",
    "UpdateScheduleRequestTypedDict",
    "UpdateScheduleResponse",
    "UpdateScheduleResponseTypedDict",
    "UpdateSweepConfigGlobals",
    "UpdateSweepConfigGlobalsTypedDict",
    "UpdateSweepConfigRequest",
    "UpdateSweepConfigRequestTypedDict",
    "UpdateSweepConfigResponse",
    "UpdateSweepConfigResponseTypedDict",
    "UpdateTicketGlobals",
    "UpdateTicketGlobalsTypedDict",
    "UpdateTicketRequest",
    "UpdateTicketRequestTypedDict",
    "UpdateTicketResponse",
    "UpdateTicketResponseTypedDict",
    "UpdateTransferGlobals",
    "UpdateTransferGlobalsTypedDict",
    "UpdateTransferRequest",
    "UpdateTransferRequestTypedDict",
    "UpdateTransferResponse",
    "UpdateTransferResponseTypedDict",
    "UpdateWalletGlobals",
    "UpdateWalletGlobalsTypedDict",
    "UpdateWalletRequest",
    "UpdateWalletRequestTypedDict",
    "UpdateWalletResponse",
    "UpdateWalletResponseTypedDict",
    "UpdateWebhookGlobals",
    "UpdateWebhookGlobalsTypedDict",
    "UpdateWebhookRequest",
    "UpdateWebhookRequestTypedDict",
    "UpdateWebhookResponse",
    "UpdateWebhookResponseTypedDict",
    "UploadDisputeEvidenceFileGlobals",
    "UploadDisputeEvidenceFileGlobalsTypedDict",
    "UploadDisputeEvidenceFileRequest",
    "UploadDisputeEvidenceFileRequestTypedDict",
    "UploadDisputeEvidenceFileResponse",
    "UploadDisputeEvidenceFileResponseTypedDict",
    "UploadDisputeEvidenceTextGlobals",
    "UploadDisputeEvidenceTextGlobalsTypedDict",
    "UploadDisputeEvidenceTextRequest",
    "UploadDisputeEvidenceTextRequestTypedDict",
    "UploadDisputeEvidenceTextResponse",
    "UploadDisputeEvidenceTextResponseTypedDict",
    "UploadFileGlobals",
    "UploadFileGlobalsTypedDict",
    "UploadFileRequest",
    "UploadFileRequestTypedDict",
    "UploadFileResponse",
    "UploadFileResponseTypedDict",
    "UploadImageGlobals",
    "UploadImageGlobalsTypedDict",
    "UploadImageRequest",
    "UploadImageRequestTypedDict",
    "UploadImageResponse",
    "UploadImageResponseTypedDict",
    "UpsertBrandGlobals",
    "UpsertBrandGlobalsTypedDict",
    "UpsertBrandRequest",
    "UpsertBrandRequestTypedDict",
    "UpsertBrandResponse",
    "UpsertBrandResponseTypedDict",
    "UpsertUnderwritingGlobals",
    "UpsertUnderwritingGlobalsTypedDict",
    "UpsertUnderwritingRequest",
    "UpsertUnderwritingRequestTypedDict",
    "UpsertUnderwritingResponse",
    "UpsertUnderwritingResponseTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AcceptDisputeGlobals": ".acceptdispute",
    "AcceptDisputeGlobalsTypedDict": ".acceptdispute",
    "AcceptDisputeRequest": ".acceptdispute",
    "AcceptDisputeRequestTypedDict": ".acceptdispute",
    "AcceptDisputeResponse": ".acceptdispute",
    "AcceptDisputeResponseTypedDict": ".acceptdispute",
    "AssignAccountCountriesGlobals": ".assignaccountcountries",
    "AssignAccountCountriesGlobalsTypedDict": ".assignaccountcountries",
    "AssignAccountCountriesRequest": ".assignaccountcountries",
    "AssignAccountCountriesRequestTypedDict": ".assignaccountcountries",
    "AssignAccountCountriesResponse": ".assignaccountcountries",
    "AssignAccountCountriesResponseTypedDict": ".assignaccountcountries",
    "CancelScheduleGlobals": ".cancelschedule",
    "CancelScheduleGlobalsTypedDict": ".cancelschedule",
    "CancelScheduleRequest": ".cancelschedule",
    "CancelScheduleRequestTypedDict": ".cancelschedule",
    "CancelScheduleResponse": ".cancelschedule",
    "CancelScheduleResponseTypedDict": ".cancelschedule",
    "CompleteBankAccountVerificationGlobals": ".completebankaccountverification",
    "CompleteBankAccountVerificationGlobalsTypedDict": ".completebankaccountverification",
    "CompleteBankAccountVerificationRequest": ".completebankaccountverification",
    "CompleteBankAccountVerificationRequestTypedDict": ".completebankaccountverification",
    "CompleteBankAccountVerificationResponse": ".completebankaccountverification",
    "CompleteBankAccountVerificationResponseTypedDict": ".completebankaccountverification",
    "CompleteMicroDepositsGlobals": ".completemicrodeposits",
    "CompleteMicroDepositsGlobalsTypedDict": ".completemicrodeposits",
    "CompleteMicroDepositsRequest": ".completemicrodeposits",
    "CompleteMicroDepositsRequestTypedDict": ".completemicrodeposits",
    "CompleteMicroDepositsResponse": ".completemicrodeposits",
    "CompleteMicroDepositsResponseTypedDict": ".completemicrodeposits",
    "ConnectAccountGlobals": ".connectaccount",
    "ConnectAccountGlobalsTypedDict": ".connectaccount",
    "ConnectAccountRequest": ".connectaccount",
    "ConnectAccountRequestTypedDict": ".connectaccount",
    "ConnectAccountResponse": ".connectaccount",
    "ConnectAccountResponseTypedDict": ".connectaccount",
    "CreateAccessTokenGlobals": ".createaccesstoken",
    "CreateAccessTokenGlobalsTypedDict": ".createaccesstoken",
    "CreateAccessTokenResponse": ".createaccesstoken",
    "CreateAccessTokenResponseTypedDict": ".createaccesstoken",
    "CreateAccountGlobals": ".createaccount",
    "CreateAccountGlobalsTypedDict": ".createaccount",
    "CreateAccountResponse": ".createaccount",
    "CreateAccountResponseTypedDict": ".createaccount",
    "CreateApplePaySessionGlobals": ".createapplepaysession",
    "CreateApplePaySessionGlobalsTypedDict": ".createapplepaysession",
    "CreateApplePaySessionRequest": ".createapplepaysession",
    "CreateApplePaySessionRequestTypedDict": ".createapplepaysession",
    "CreateApplePaySessionResponse": ".createapplepaysession",
    "CreateApplePaySessionResponseTypedDict": ".createapplepaysession",
    "CreateBrandGlobals": ".createbrand",
    "CreateBrandGlobalsTypedDict": ".createbrand",
    "CreateBrandRequest": ".createbrand",
    "CreateBrandRequestTypedDict": ".createbrand",
    "CreateBrandResponse": ".createbrand",
    "CreateBrandResponseTypedDict": ".createbrand",
    "CreateCancellationGlobals": ".createcancellation",
    "CreateCancellationGlobalsTypedDict": ".createcancellation",
    "CreateCancellationRequest": ".createcancellation",
    "CreateCancellationRequestTypedDict": ".createcancellation",
    "CreateCancellationResponse": ".createcancellation",
    "CreateCancellationResponseTypedDict": ".createcancellation",
    "CreateFeePlanAgreementsGlobals": ".createfeeplanagreements",
    "CreateFeePlanAgreementsGlobalsTypedDict": ".createfeeplanagreements",
    "CreateFeePlanAgreementsRequest": ".createfeeplanagreements",
    "CreateFeePlanAgreementsRequestTypedDict": ".createfeeplanagreements",
    "CreateFeePlanAgreementsResponse": ".createfeeplanagreements",
    "CreateFeePlanAgreementsResponseTypedDict": ".createfeeplanagreements",
    "CreateInvoiceGlobals": ".createinvoice",
    "CreateInvoiceGlobalsTypedDict": ".createinvoice",
    "CreateInvoiceRequest": ".createinvoice",
    "CreateInvoiceRequestTypedDict": ".createinvoice",
    "CreateInvoiceResponse": ".createinvoice",
    "CreateInvoiceResponseTypedDict": ".createinvoice",
    "CreateInvoicePaymentGlobals": ".createinvoicepayment",
    "CreateInvoicePaymentGlobalsTypedDict": ".createinvoicepayment",
    "CreateInvoicePaymentRequest": ".createinvoicepayment",
    "CreateInvoicePaymentRequestTypedDict": ".createinvoicepayment",
    "CreateInvoicePaymentResponse": ".createinvoicepayment",
    "CreateInvoicePaymentResponseTypedDict": ".createinvoicepayment",
    "CreateOnboardingInviteGlobals": ".createonboardinginvite",
    "CreateOnboardingInviteGlobalsTypedDict": ".createonboardinginvite",
    "CreateOnboardingInviteResponse": ".createonboardinginvite",
    "CreateOnboardingInviteResponseTypedDict": ".createonboardinginvite",
    "CreatePaymentLinkGlobals": ".createpaymentlink",
    "CreatePaymentLinkGlobalsTypedDict": ".createpaymentlink",
    "CreatePaymentLinkRequest": ".createpaymentlink",
    "CreatePaymentLinkRequestTypedDict": ".createpaymentlink",
    "CreatePaymentLinkResponse": ".createpaymentlink",
    "CreatePaymentLinkResponseTypedDict": ".createpaymentlink",
    "CreateProductGlobals": ".createproduct",
    "CreateProductGlobalsTypedDict": ".createproduct",
    "CreateProductRequest": ".createproduct",
    "CreateProductRequestTypedDict": ".createproduct",
    "CreateProductResponse": ".createproduct",
    "CreateProductResponseTypedDict": ".createproduct",
    "CreateReceiptsGlobals": ".createreceipts",
    "CreateReceiptsGlobalsTypedDict": ".createreceipts",
    "CreateReceiptsResponse": ".createreceipts",
    "CreateReceiptsResponseTypedDict": ".createreceipts",
    "CreateRepresentativeGlobals": ".createrepresentative",
    "CreateRepresentativeGlobalsTypedDict": ".createrepresentative",
    "CreateRepresentativeRequest": ".createrepresentative",
    "CreateRepresentativeRequestTypedDict": ".createrepresentative",
    "CreateRepresentativeResponse": ".createrepresentative",
    "CreateRepresentativeResponseTypedDict": ".createrepresentative",
    "CreateReversalGlobals": ".createreversal",
    "CreateReversalGlobalsTypedDict": ".createreversal",
    "CreateReversalRequest": ".createreversal",
    "CreateReversalRequestTypedDict": ".createreversal",
    "CreateReversalResponse": ".createreversal",
    "CreateReversalResponseTypedDict": ".createreversal",
    "CreateScheduleGlobals": ".createschedule",
    "CreateScheduleGlobalsTypedDict": ".createschedule",
    "CreateScheduleRequest": ".createschedule",
    "CreateScheduleRequestTypedDict": ".createschedule",
    "CreateScheduleResponse": ".createschedule",
    "CreateScheduleResponseTypedDict": ".createschedule",
    "CreateSweepConfigGlobals": ".createsweepconfig",
    "CreateSweepConfigGlobalsTypedDict": ".createsweepconfig",
    "CreateSweepConfigRequest": ".createsweepconfig",
    "CreateSweepConfigRequestTypedDict": ".createsweepconfig",
    "CreateSweepConfigResponse": ".createsweepconfig",
    "CreateSweepConfigResponseTypedDict": ".createsweepconfig",
    "CreateTerminalApplicationGlobals": ".createterminalapplication",
    "CreateTerminalApplicationGlobalsTypedDict": ".createterminalapplication",
    "CreateTerminalApplicationResponse": ".createterminalapplication",
    "CreateTerminalApplicationResponseTypedDict": ".createterminalapplication",
    "CreateTerminalApplicationVersionGlobals": ".createterminalapplicationversion",
    "CreateTerminalApplicationVersionGlobalsTypedDict": ".createterminalapplicationversion",
    "CreateTerminalApplicationVersionRequest": ".createterminalapplicationversion",
    "CreateTerminalApplicationVersionRequestTypedDict": ".createterminalapplicationversion",
    "CreateTerminalApplicationVersionResponse": ".createterminalapplicationversion",
    "CreateTerminalApplicationVersionResponseTypedDict": ".createterminalapplicationversion",
    "CreateTicketGlobals": ".createticket",
    "CreateTicketGlobalsTypedDict": ".createticket",
    "CreateTicketRequest": ".createticket",
    "CreateTicketRequestTypedDict": ".createticket",
    "CreateTicketResponse": ".createticket",
    "CreateTicketResponseTypedDict": ".createticket",
    "CreateTransferGlobals": ".createtransfer",
    "CreateTransferGlobalsTypedDict": ".createtransfer",
    "CreateTransferRequest": ".createtransfer",
    "CreateTransferRequestTypedDict": ".createtransfer",
    "CreateTransferResponse": ".createtransfer",
    "CreateTransferResponseResult": ".createtransfer",
    "CreateTransferResponseResultTypedDict": ".createtransfer",
    "CreateTransferResponseTypedDict": ".createtransfer",
    "CreateTransferOptionsGlobals": ".createtransferoptions",
    "CreateTransferOptionsGlobalsTypedDict": ".createtransferoptions",
    "CreateTransferOptionsRequest": ".createtransferoptions",
    "CreateTransferOptionsRequestTypedDict": ".createtransferoptions",
    "CreateTransferOptionsResponse": ".createtransferoptions",
    "CreateTransferOptionsResponseTypedDict": ".createtransferoptions",
    "CreateWalletGlobals": ".createwallet",
    "CreateWalletGlobalsTypedDict": ".createwallet",
    "CreateWalletRequest": ".createwallet",
    "CreateWalletRequestTypedDict": ".createwallet",
    "CreateWalletResponse": ".createwallet",
    "CreateWalletResponseTypedDict": ".createwallet",
    "CreateWebhookGlobals": ".createwebhook",
    "CreateWebhookGlobalsTypedDict": ".createwebhook",
    "CreateWebhookResponse": ".createwebhook",
    "CreateWebhookResponseTypedDict": ".createwebhook",
    "DeleteDisputeEvidenceFileGlobals": ".deletedisputeevidencefile",
    "DeleteDisputeEvidenceFileGlobalsTypedDict": ".deletedisputeevidencefile",
    "DeleteDisputeEvidenceFileRequest": ".deletedisputeevidencefile",
    "DeleteDisputeEvidenceFileRequestTypedDict": ".deletedisputeevidencefile",
    "DeleteDisputeEvidenceFileResponse": ".deletedisputeevidencefile",
    "DeleteDisputeEvidenceFileResponseTypedDict": ".deletedisputeevidencefile",
    "DeleteImageGlobals": ".deleteimage",
    "DeleteImageGlobalsTypedDict": ".deleteimage",
    "DeleteImageRequest": ".deleteimage",
    "DeleteImageRequestTypedDict": ".deleteimage",
    "DeleteImageResponse": ".deleteimage",
    "DeleteImageResponseTypedDict": ".deleteimage",
    "DeleteInvoiceGlobals": ".deleteinvoice",
    "DeleteInvoiceGlobalsTypedDict": ".deleteinvoice",
    "DeleteInvoiceRequest": ".deleteinvoice",
    "DeleteInvoiceRequestTypedDict": ".deleteinvoice",
    "DeleteInvoiceResponse": ".deleteinvoice",
    "DeleteInvoiceResponseTypedDict": ".deleteinvoice",
    "DeleteRepresentativeGlobals": ".deleterepresentative",
    "DeleteRepresentativeGlobalsTypedDict": ".deleterepresentative",
    "DeleteRepresentativeRequest": ".deleterepresentative",
    "DeleteRepresentativeRequestTypedDict": ".deleterepresentative",
    "DeleteRepresentativeResponse": ".deleterepresentative",
    "DeleteRepresentativeResponseTypedDict": ".deleterepresentative",
    "DeleteTerminalApplicationGlobals": ".deleteterminalapplication",
    "DeleteTerminalApplicationGlobalsTypedDict": ".deleteterminalapplication",
    "DeleteTerminalApplicationRequest": ".deleteterminalapplication",
    "DeleteTerminalApplicationRequestTypedDict": ".deleteterminalapplication",
    "DeleteTerminalApplicationResponse": ".deleteterminalapplication",
    "DeleteTerminalApplicationResponseTypedDict": ".deleteterminalapplication",
    "DisableBankAccountGlobals": ".disablebankaccount",
    "DisableBankAccountGlobalsTypedDict": ".disablebankaccount",
    "DisableBankAccountRequest": ".disablebankaccount",
    "DisableBankAccountRequestTypedDict": ".disablebankaccount",
    "DisableBankAccountResponse": ".disablebankaccount",
    "DisableBankAccountResponseTypedDict": ".disablebankaccount",
    "DisableCapabilityGlobals": ".disablecapability",
    "DisableCapabilityGlobalsTypedDict": ".disablecapability",
    "DisableCapabilityRequest": ".disablecapability",
    "DisableCapabilityRequestTypedDict": ".disablecapability",
    "DisableCapabilityResponse": ".disablecapability",
    "DisableCapabilityResponseTypedDict": ".disablecapability",
    "DisableCardGlobals": ".disablecard",
    "DisableCardGlobalsTypedDict": ".disablecard",
    "DisableCardRequest": ".disablecard",
    "DisableCardRequestTypedDict": ".disablecard",
    "DisableCardResponse": ".disablecard",
    "DisableCardResponseTypedDict": ".disablecard",
    "DisablePaymentLinkGlobals": ".disablepaymentlink",
    "DisablePaymentLinkGlobalsTypedDict": ".disablepaymentlink",
    "DisablePaymentLinkRequest": ".disablepaymentlink",
    "DisablePaymentLinkRequestTypedDict": ".disablepaymentlink",
    "DisablePaymentLinkResponse": ".disablepaymentlink",
    "DisablePaymentLinkResponseTypedDict": ".disablepaymentlink",
    "DisableProductGlobals": ".disableproduct",
    "DisableProductGlobalsTypedDict": ".disableproduct",
    "DisableProductRequest": ".disableproduct",
    "DisableProductRequestTypedDict": ".disableproduct",
    "DisableProductResponse": ".disableproduct",
    "DisableProductResponseTypedDict": ".disableproduct",
    "DisableWebhookGlobals": ".disablewebhook",
    "DisableWebhookGlobalsTypedDict": ".disablewebhook",
    "DisableWebhookRequest": ".disablewebhook",
    "DisableWebhookRequestTypedDict": ".disablewebhook",
    "DisableWebhookResponse": ".disablewebhook",
    "DisableWebhookResponseTypedDict": ".disablewebhook",
    "DisconnectAccountGlobals": ".disconnectaccount",
    "DisconnectAccountGlobalsTypedDict": ".disconnectaccount",
    "DisconnectAccountRequest": ".disconnectaccount",
    "DisconnectAccountRequestTypedDict": ".disconnectaccount",
    "DisconnectAccountResponse": ".disconnectaccount",
    "DisconnectAccountResponseTypedDict": ".disconnectaccount",
    "GenerateEndToEndKeyGlobals": ".generateendtoendkey",
    "GenerateEndToEndKeyGlobalsTypedDict": ".generateendtoendkey",
    "GenerateEndToEndKeyRequest": ".generateendtoendkey",
    "GenerateEndToEndKeyRequestTypedDict": ".generateendtoendkey",
    "GenerateEndToEndKeyResponse": ".generateendtoendkey",
    "GenerateEndToEndKeyResponseTypedDict": ".generateendtoendkey",
    "GetAccountGlobals": ".getaccount",
    "GetAccountGlobalsTypedDict": ".getaccount",
    "GetAccountRequest": ".getaccount",
    "GetAccountRequestTypedDict": ".getaccount",
    "GetAccountResponse": ".getaccount",
    "GetAccountResponseTypedDict": ".getaccount",
    "GetAccountCountriesGlobals": ".getaccountcountries",
    "GetAccountCountriesGlobalsTypedDict": ".getaccountcountries",
    "GetAccountCountriesRequest": ".getaccountcountries",
    "GetAccountCountriesRequestTypedDict": ".getaccountcountries",
    "GetAccountCountriesResponse": ".getaccountcountries",
    "GetAccountCountriesResponseTypedDict": ".getaccountcountries",
    "GetAccountTerminalApplicationGlobals": ".getaccountterminalapplication",
    "GetAccountTerminalApplicationGlobalsTypedDict": ".getaccountterminalapplication",
    "GetAccountTerminalApplicationRequest": ".getaccountterminalapplication",
    "GetAccountTerminalApplicationRequestTypedDict": ".getaccountterminalapplication",
    "GetAccountTerminalApplicationResponse": ".getaccountterminalapplication",
    "GetAccountTerminalApplicationResponseTypedDict": ".getaccountterminalapplication",
    "GetAdjustmentGlobals": ".getadjustment",
    "GetAdjustmentGlobalsTypedDict": ".getadjustment",
    "GetAdjustmentRequest": ".getadjustment",
    "GetAdjustmentRequestTypedDict": ".getadjustment",
    "GetAdjustmentResponse": ".getadjustment",
    "GetAdjustmentResponseTypedDict": ".getadjustment",
    "GetApplePayMerchantDomainsGlobals": ".getapplepaymerchantdomains",
    "GetApplePayMerchantDomainsGlobalsTypedDict": ".getapplepaymerchantdomains",
    "GetApplePayMerchantDomainsRequest": ".getapplepaymerchantdomains",
    "GetApplePayMerchantDomainsRequestTypedDict": ".getapplepaymerchantdomains",
    "GetApplePayMerchantDomainsResponse": ".getapplepaymerchantdomains",
    "GetApplePayMerchantDomainsResponseTypedDict": ".getapplepaymerchantdomains",
    "GetAvatarGlobals": ".getavatar",
    "GetAvatarGlobalsTypedDict": ".getavatar",
    "GetAvatarRequest": ".getavatar",
    "GetAvatarRequestTypedDict": ".getavatar",
    "GetAvatarResponse": ".getavatar",
    "GetAvatarResponseTypedDict": ".getavatar",
    "GetBankAccountGlobals": ".getbankaccount",
    "GetBankAccountGlobalsTypedDict": ".getbankaccount",
    "GetBankAccountRequest": ".getbankaccount",
    "GetBankAccountRequestTypedDict": ".getbankaccount",
    "GetBankAccountResponse": ".getbankaccount",
    "GetBankAccountResponseTypedDict": ".getbankaccount",
    "GetBankAccountVerificationGlobals": ".getbankaccountverification",
    "GetBankAccountVerificationGlobalsTypedDict": ".getbankaccountverification",
    "GetBankAccountVerificationRequest": ".getbankaccountverification",
    "GetBankAccountVerificationRequestTypedDict": ".getbankaccountverification",
    "GetBankAccountVerificationResponse": ".getbankaccountverification",
    "GetBankAccountVerificationResponseTypedDict": ".getbankaccountverification",
    "GetBrandGlobals": ".getbrand",
    "GetBrandGlobalsTypedDict": ".getbrand",
    "GetBrandRequest": ".getbrand",
    "GetBrandRequestTypedDict": ".getbrand",
    "GetBrandResponse": ".getbrand",
    "GetBrandResponseTypedDict": ".getbrand",
    "GetCancellationGlobals": ".getcancellation",
    "GetCancellationGlobalsTypedDict": ".getcancellation",
    "GetCancellationRequest": ".getcancellation",
    "GetCancellationRequestTypedDict": ".getcancellation",
    "GetCancellationResponse": ".getcancellation",
    "GetCancellationResponseTypedDict": ".getcancellation",
    "GetCapabilityGlobals": ".getcapability",
    "GetCapabilityGlobalsTypedDict": ".getcapability",
    "GetCapabilityRequest": ".getcapability",
    "GetCapabilityRequestTypedDict": ".getcapability",
    "GetCapabilityResponse": ".getcapability",
    "GetCapabilityResponseTypedDict": ".getcapability",
    "GetCardGlobals": ".getcard",
    "GetCardGlobalsTypedDict": ".getcard",
    "GetCardRequest": ".getcard",
    "GetCardRequestTypedDict": ".getcard",
    "GetCardResponse": ".getcard",
    "GetCardResponseTypedDict": ".getcard",
    "GetDisputeGlobals": ".getdispute",
    "GetDisputeGlobalsTypedDict": ".getdispute",
    "GetDisputeRequest": ".getdispute",
    "GetDisputeRequestTypedDict": ".getdispute",
    "GetDisputeResponse": ".getdispute",
    "GetDisputeResponseTypedDict": ".getdispute",
    "GetDisputeEvidenceGlobals": ".getdisputeevidence",
    "GetDisputeEvidenceGlobalsTypedDict": ".getdisputeevidence",
    "GetDisputeEvidenceRequest": ".getdisputeevidence",
    "GetDisputeEvidenceRequestTypedDict": ".getdisputeevidence",
    "GetDisputeEvidenceResponse": ".getdisputeevidence",
    "GetDisputeEvidenceResponseTypedDict": ".getdisputeevidence",
    "GetDisputeEvidenceDataGlobals": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataGlobalsTypedDict": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataRequest": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataRequestTypedDict": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataResponse": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataResponseResult": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataResponseResultTypedDict": ".getdisputeevidencedata",
    "GetDisputeEvidenceDataResponseTypedDict": ".getdisputeevidencedata",
    "GetEnrichmentAddressGlobals": ".getenrichmentaddress",
    "GetEnrichmentAddressGlobalsTypedDict": ".getenrichmentaddress",
    "GetEnrichmentAddressRequest": ".getenrichmentaddress",
    "GetEnrichmentAddressRequestTypedDict": ".getenrichmentaddress",
    "GetEnrichmentAddressResponse": ".getenrichmentaddress",
    "GetEnrichmentAddressResponseTypedDict": ".getenrichmentaddress",
    "GetEnrichmentProfileGlobals": ".getenrichmentprofile",
    "GetEnrichmentProfileGlobalsTypedDict": ".getenrichmentprofile",
    "GetEnrichmentProfileRequest": ".getenrichmentprofile",
    "GetEnrichmentProfileRequestTypedDict": ".getenrichmentprofile",
    "GetEnrichmentProfileResponse": ".getenrichmentprofile",
    "GetEnrichmentProfileResponseTypedDict": ".getenrichmentprofile",
    "GetFileDetailsGlobals": ".getfiledetails",
    "GetFileDetailsGlobalsTypedDict": ".getfiledetails",
    "GetFileDetailsRequest": ".getfiledetails",
    "GetFileDetailsRequestTypedDict": ".getfiledetails",
    "GetFileDetailsResponse": ".getfiledetails",
    "GetFileDetailsResponseTypedDict": ".getfiledetails",
    "GetFullIssuedCardGlobals": ".getfullissuedcard",
    "GetFullIssuedCardGlobalsTypedDict": ".getfullissuedcard",
    "GetFullIssuedCardRequest": ".getfullissuedcard",
    "GetFullIssuedCardRequestTypedDict": ".getfullissuedcard",
    "GetFullIssuedCardResponse": ".getfullissuedcard",
    "GetFullIssuedCardResponseTypedDict": ".getfullissuedcard",
    "GetImageMetadataGlobals": ".getimagemetadata",
    "GetImageMetadataGlobalsTypedDict": ".getimagemetadata",
    "GetImageMetadataRequest": ".getimagemetadata",
    "GetImageMetadataRequestTypedDict": ".getimagemetadata",
    "GetImageMetadataResponse": ".getimagemetadata",
    "GetImageMetadataResponseTypedDict": ".getimagemetadata",
    "GetInvoiceGlobals": ".getinvoice",
    "GetInvoiceGlobalsTypedDict": ".getinvoice",
    "GetInvoiceRequest": ".getinvoice",
    "GetInvoiceRequestTypedDict": ".getinvoice",
    "GetInvoiceResponse": ".getinvoice",
    "GetInvoiceResponseTypedDict": ".getinvoice",
    "GetIssuedCardGlobals": ".getissuedcard",
    "GetIssuedCardGlobalsTypedDict": ".getissuedcard",
    "GetIssuedCardRequest": ".getissuedcard",
    "GetIssuedCardRequestTypedDict": ".getissuedcard",
    "GetIssuedCardResponse": ".getissuedcard",
    "GetIssuedCardResponseTypedDict": ".getissuedcard",
    "GetIssuedCardAuthorizationGlobals": ".getissuedcardauthorization",
    "GetIssuedCardAuthorizationGlobalsTypedDict": ".getissuedcardauthorization",
    "GetIssuedCardAuthorizationRequest": ".getissuedcardauthorization",
    "GetIssuedCardAuthorizationRequestTypedDict": ".getissuedcardauthorization",
    "GetIssuedCardAuthorizationResponse": ".getissuedcardauthorization",
    "GetIssuedCardAuthorizationResponseTypedDict": ".getissuedcardauthorization",
    "GetIssuedCardTransactionGlobals": ".getissuedcardtransaction",
    "GetIssuedCardTransactionGlobalsTypedDict": ".getissuedcardtransaction",
    "GetIssuedCardTransactionRequest": ".getissuedcardtransaction",
    "GetIssuedCardTransactionRequestTypedDict": ".getissuedcardtransaction",
    "GetIssuedCardTransactionResponse": ".getissuedcardtransaction",
    "GetIssuedCardTransactionResponseTypedDict": ".getissuedcardtransaction",
    "GetMerchantProcessingAgreementGlobals": ".getmerchantprocessingagreement",
    "GetMerchantProcessingAgreementGlobalsTypedDict": ".getmerchantprocessingagreement",
    "GetMerchantProcessingAgreementRequest": ".getmerchantprocessingagreement",
    "GetMerchantProcessingAgreementRequestTypedDict": ".getmerchantprocessingagreement",
    "GetMerchantProcessingAgreementResponse": ".getmerchantprocessingagreement",
    "GetMerchantProcessingAgreementResponseTypedDict": ".getmerchantprocessingagreement",
    "GetOnboardingInviteGlobals": ".getonboardinginvite",
    "GetOnboardingInviteGlobalsTypedDict": ".getonboardinginvite",
    "GetOnboardingInviteRequest": ".getonboardinginvite",
    "GetOnboardingInviteRequestTypedDict": ".getonboardinginvite",
    "GetOnboardingInviteResponse": ".getonboardinginvite",
    "GetOnboardingInviteResponseTypedDict": ".getonboardinginvite",
    "GetPaymentLinkGlobals": ".getpaymentlink",
    "GetPaymentLinkGlobalsTypedDict": ".getpaymentlink",
    "GetPaymentLinkRequest": ".getpaymentlink",
    "GetPaymentLinkRequestTypedDict": ".getpaymentlink",
    "GetPaymentLinkResponse": ".getpaymentlink",
    "GetPaymentLinkResponseTypedDict": ".getpaymentlink",
    "GetPaymentLinkQRCodeGlobals": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeGlobalsTypedDict": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeRequest": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeRequestTypedDict": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeResponse": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeResponseResult": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeResponseResultTypedDict": ".getpaymentlinkqrcode",
    "GetPaymentLinkQRCodeResponseTypedDict": ".getpaymentlinkqrcode",
    "GetPaymentMethodGlobals": ".getpaymentmethod",
    "GetPaymentMethodGlobalsTypedDict": ".getpaymentmethod",
    "GetPaymentMethodRequest": ".getpaymentmethod",
    "GetPaymentMethodRequestTypedDict": ".getpaymentmethod",
    "GetPaymentMethodResponse": ".getpaymentmethod",
    "GetPaymentMethodResponseTypedDict": ".getpaymentmethod",
    "GetProductGlobals": ".getproduct",
    "GetProductGlobalsTypedDict": ".getproduct",
    "GetProductRequest": ".getproduct",
    "GetProductRequestTypedDict": ".getproduct",
    "GetProductResponse": ".getproduct",
    "GetProductResponseTypedDict": ".getproduct",
    "GetPublicImageRequest": ".getpublicimage",
    "GetPublicImageRequestTypedDict": ".getpublicimage",
    "GetPublicImageResponse": ".getpublicimage",
    "GetPublicImageResponseResult": ".getpublicimage",
    "GetPublicImageResponseResultTypedDict": ".getpublicimage",
    "GetPublicImageResponseTypedDict": ".getpublicimage",
    "GetRefundGlobals": ".getrefund",
    "GetRefundGlobalsTypedDict": ".getrefund",
    "GetRefundRequest": ".getrefund",
    "GetRefundRequestTypedDict": ".getrefund",
    "GetRefundResponse": ".getrefund",
    "GetRefundResponseTypedDict": ".getrefund",
    "GetRepresentativeGlobals": ".getrepresentative",
    "GetRepresentativeGlobalsTypedDict": ".getrepresentative",
    "GetRepresentativeRequest": ".getrepresentative",
    "GetRepresentativeRequestTypedDict": ".getrepresentative",
    "GetRepresentativeResponse": ".getrepresentative",
    "GetRepresentativeResponseTypedDict": ".getrepresentative",
    "GetResidualGlobals": ".getresidual",
    "GetResidualGlobalsTypedDict": ".getresidual",
    "GetResidualRequest": ".getresidual",
    "GetResidualRequestTypedDict": ".getresidual",
    "GetResidualResponse": ".getresidual",
    "GetResidualResponseTypedDict": ".getresidual",
    "GetScheduledOccurrenceGlobals": ".getscheduledoccurrence",
    "GetScheduledOccurrenceGlobalsTypedDict": ".getscheduledoccurrence",
    "GetScheduledOccurrenceRequest": ".getscheduledoccurrence",
    "GetScheduledOccurrenceRequestTypedDict": ".getscheduledoccurrence",
    "GetScheduledOccurrenceResponse": ".getscheduledoccurrence",
    "GetScheduledOccurrenceResponseTypedDict": ".getscheduledoccurrence",
    "GetSchedulesGlobals": ".getschedules",
    "GetSchedulesGlobalsTypedDict": ".getschedules",
    "GetSchedulesRequest": ".getschedules",
    "GetSchedulesRequestTypedDict": ".getschedules",
    "GetSchedulesResponse": ".getschedules",
    "GetSchedulesResponseTypedDict": ".getschedules",
    "GetStatementGlobals": ".getstatement",
    "GetStatementGlobalsTypedDict": ".getstatement",
    "GetStatementRequest": ".getstatement",
    "GetStatementRequestTypedDict": ".getstatement",
    "GetStatementResponse": ".getstatement",
    "GetStatementResponseResult": ".getstatement",
    "GetStatementResponseResultTypedDict": ".getstatement",
    "GetStatementResponseTypedDict": ".getstatement",
    "GetSweepGlobals": ".getsweep",
    "GetSweepGlobalsTypedDict": ".getsweep",
    "GetSweepRequest": ".getsweep",
    "GetSweepRequestTypedDict": ".getsweep",
    "GetSweepResponse": ".getsweep",
    "GetSweepResponseTypedDict": ".getsweep",
    "GetSweepConfigGlobals": ".getsweepconfig",
    "GetSweepConfigGlobalsTypedDict": ".getsweepconfig",
    "GetSweepConfigRequest": ".getsweepconfig",
    "GetSweepConfigRequestTypedDict": ".getsweepconfig",
    "GetSweepConfigResponse": ".getsweepconfig",
    "GetSweepConfigResponseTypedDict": ".getsweepconfig",
    "GetTerminalApplicationGlobals": ".getterminalapplication",
    "GetTerminalApplicationGlobalsTypedDict": ".getterminalapplication",
    "GetTerminalApplicationRequest": ".getterminalapplication",
    "GetTerminalApplicationRequestTypedDict": ".getterminalapplication",
    "GetTerminalApplicationResponse": ".getterminalapplication",
    "GetTerminalApplicationResponseTypedDict": ".getterminalapplication",
    "GetTerminalConfigurationGlobals": ".getterminalconfiguration",
    "GetTerminalConfigurationGlobalsTypedDict": ".getterminalconfiguration",
    "GetTerminalConfigurationRequest": ".getterminalconfiguration",
    "GetTerminalConfigurationRequestTypedDict": ".getterminalconfiguration",
    "GetTerminalConfigurationResponse": ".getterminalconfiguration",
    "GetTerminalConfigurationResponseTypedDict": ".getterminalconfiguration",
    "GetTermsOfServiceTokenGlobals": ".gettermsofservicetoken",
    "GetTermsOfServiceTokenGlobalsTypedDict": ".gettermsofservicetoken",
    "GetTermsOfServiceTokenRequest": ".gettermsofservicetoken",
    "GetTermsOfServiceTokenRequestTypedDict": ".gettermsofservicetoken",
    "GetTermsOfServiceTokenResponse": ".gettermsofservicetoken",
    "GetTermsOfServiceTokenResponseTypedDict": ".gettermsofservicetoken",
    "GetTicketGlobals": ".getticket",
    "GetTicketGlobalsTypedDict": ".getticket",
    "GetTicketRequest": ".getticket",
    "GetTicketRequestTypedDict": ".getticket",
    "GetTicketResponse": ".getticket",
    "GetTicketResponseTypedDict": ".getticket",
    "GetTransferGlobals": ".gettransfer",
    "GetTransferGlobalsTypedDict": ".gettransfer",
    "GetTransferRequest": ".gettransfer",
    "GetTransferRequestTypedDict": ".gettransfer",
    "GetTransferResponse": ".gettransfer",
    "GetTransferResponseTypedDict": ".gettransfer",
    "GetUnderwritingGlobals": ".getunderwriting",
    "GetUnderwritingGlobalsTypedDict": ".getunderwriting",
    "GetUnderwritingRequest": ".getunderwriting",
    "GetUnderwritingRequestTypedDict": ".getunderwriting",
    "GetUnderwritingResponse": ".getunderwriting",
    "GetUnderwritingResponseTypedDict": ".getunderwriting",
    "GetWalletGlobals": ".getwallet",
    "GetWalletGlobalsTypedDict": ".getwallet",
    "GetWalletRequest": ".getwallet",
    "GetWalletRequestTypedDict": ".getwallet",
    "GetWalletResponse": ".getwallet",
    "GetWalletResponseTypedDict": ".getwallet",
    "GetWalletTransactionGlobals": ".getwallettransaction",
    "GetWalletTransactionGlobalsTypedDict": ".getwallettransaction",
    "GetWalletTransactionRequest": ".getwallettransaction",
    "GetWalletTransactionRequestTypedDict": ".getwallettransaction",
    "GetWalletTransactionResponse": ".getwallettransaction",
    "GetWalletTransactionResponseTypedDict": ".getwallettransaction",
    "GetWebhookGlobals": ".getwebhook",
    "GetWebhookGlobalsTypedDict": ".getwebhook",
    "GetWebhookRequest": ".getwebhook",
    "GetWebhookRequestTypedDict": ".getwebhook",
    "GetWebhookResponse": ".getwebhook",
    "GetWebhookResponseTypedDict": ".getwebhook",
    "GetWebhookSecretGlobals": ".getwebhooksecret",
    "GetWebhookSecretGlobalsTypedDict": ".getwebhooksecret",
    "GetWebhookSecretRequest": ".getwebhooksecret",
    "GetWebhookSecretRequestTypedDict": ".getwebhooksecret",
    "GetWebhookSecretResponse": ".getwebhooksecret",
    "GetWebhookSecretResponseTypedDict": ".getwebhooksecret",
    "InitiateBankAccountVerificationGlobals": ".initiatebankaccountverification",
    "InitiateBankAccountVerificationGlobalsTypedDict": ".initiatebankaccountverification",
    "InitiateBankAccountVerificationRequest": ".initiatebankaccountverification",
    "InitiateBankAccountVerificationRequestTypedDict": ".initiatebankaccountverification",
    "InitiateBankAccountVerificationResponse": ".initiatebankaccountverification",
    "InitiateBankAccountVerificationResponseTypedDict": ".initiatebankaccountverification",
    "InitiateMicroDepositsGlobals": ".initiatemicrodeposits",
    "InitiateMicroDepositsGlobalsTypedDict": ".initiatemicrodeposits",
    "InitiateMicroDepositsRequest": ".initiatemicrodeposits",
    "InitiateMicroDepositsRequestTypedDict": ".initiatemicrodeposits",
    "InitiateMicroDepositsResponse": ".initiatemicrodeposits",
    "InitiateMicroDepositsResponseTypedDict": ".initiatemicrodeposits",
    "InitiateRefundGlobals": ".initiaterefund",
    "InitiateRefundGlobalsTypedDict": ".initiaterefund",
    "InitiateRefundRequest": ".initiaterefund",
    "InitiateRefundRequestTypedDict": ".initiaterefund",
    "InitiateRefundResponse": ".initiaterefund",
    "InitiateRefundResponseResult": ".initiaterefund",
    "InitiateRefundResponseResultTypedDict": ".initiaterefund",
    "InitiateRefundResponseTypedDict": ".initiaterefund",
    "LinkAccountTerminalApplicationGlobals": ".linkaccountterminalapplication",
    "LinkAccountTerminalApplicationGlobalsTypedDict": ".linkaccountterminalapplication",
    "LinkAccountTerminalApplicationRequest": ".linkaccountterminalapplication",
    "LinkAccountTerminalApplicationRequestTypedDict": ".linkaccountterminalapplication",
    "LinkAccountTerminalApplicationResponse": ".linkaccountterminalapplication",
    "LinkAccountTerminalApplicationResponseTypedDict": ".linkaccountterminalapplication",
    "LinkApplePayTokenGlobals": ".linkapplepaytoken",
    "LinkApplePayTokenGlobalsTypedDict": ".linkapplepaytoken",
    "LinkApplePayTokenRequest": ".linkapplepaytoken",
    "LinkApplePayTokenRequestTypedDict": ".linkapplepaytoken",
    "LinkApplePayTokenResponse": ".linkapplepaytoken",
    "LinkApplePayTokenResponseTypedDict": ".linkapplepaytoken",
    "LinkBankAccountGlobals": ".linkbankaccount",
    "LinkBankAccountGlobalsTypedDict": ".linkbankaccount",
    "LinkBankAccountRequest": ".linkbankaccount",
    "LinkBankAccountRequestTypedDict": ".linkbankaccount",
    "LinkBankAccountResponse": ".linkbankaccount",
    "LinkBankAccountResponseTypedDict": ".linkbankaccount",
    "LinkCardGlobals": ".linkcard",
    "LinkCardGlobalsTypedDict": ".linkcard",
    "LinkCardRequest": ".linkcard",
    "LinkCardRequestTypedDict": ".linkcard",
    "LinkCardResponse": ".linkcard",
    "LinkCardResponseTypedDict": ".linkcard",
    "ListAccountsGlobals": ".listaccounts",
    "ListAccountsGlobalsTypedDict": ".listaccounts",
    "ListAccountsRequest": ".listaccounts",
    "ListAccountsRequestTypedDict": ".listaccounts",
    "ListAccountsResponse": ".listaccounts",
    "ListAccountsResponseTypedDict": ".listaccounts",
    "ListAccountTerminalApplicationsGlobals": ".listaccountterminalapplications",
    "ListAccountTerminalApplicationsGlobalsTypedDict": ".listaccountterminalapplications",
    "ListAccountTerminalApplicationsRequest": ".listaccountterminalapplications",
    "ListAccountTerminalApplicationsRequestTypedDict": ".listaccountterminalapplications",
    "ListAccountTerminalApplicationsResponse": ".listaccountterminalapplications",
    "ListAccountTerminalApplicationsResponseTypedDict": ".listaccountterminalapplications",
    "ListAdjustmentsGlobals": ".listadjustments",
    "ListAdjustmentsGlobalsTypedDict": ".listadjustments",
    "ListAdjustmentsRequest": ".listadjustments",
    "ListAdjustmentsRequestTypedDict": ".listadjustments",
    "ListAdjustmentsResponse": ".listadjustments",
    "ListAdjustmentsResponseTypedDict": ".listadjustments",
    "ListBankAccountsGlobals": ".listbankaccounts",
    "ListBankAccountsGlobalsTypedDict": ".listbankaccounts",
    "ListBankAccountsRequest": ".listbankaccounts",
    "ListBankAccountsRequestTypedDict": ".listbankaccounts",
    "ListBankAccountsResponse": ".listbankaccounts",
    "ListBankAccountsResponseTypedDict": ".listbankaccounts",
    "ListCapabilitiesGlobals": ".listcapabilities",
    "ListCapabilitiesGlobalsTypedDict": ".listcapabilities",
    "ListCapabilitiesRequest": ".listcapabilities",
    "ListCapabilitiesRequestTypedDict": ".listcapabilities",
    "ListCapabilitiesResponse": ".listcapabilities",
    "ListCapabilitiesResponseTypedDict": ".listcapabilities",
    "ListCardsGlobals": ".listcards",
    "ListCardsGlobalsTypedDict": ".listcards",
    "ListCardsRequest": ".listcards",
    "ListCardsRequestTypedDict": ".listcards",
    "ListCardsResponse": ".listcards",
    "ListCardsResponseTypedDict": ".listcards",
    "ListConnectedAccountsForAccountGlobals": ".listconnectedaccountsforaccount",
    "ListConnectedAccountsForAccountGlobalsTypedDict": ".listconnectedaccountsforaccount",
    "ListConnectedAccountsForAccountRequest": ".listconnectedaccountsforaccount",
    "ListConnectedAccountsForAccountRequestTypedDict": ".listconnectedaccountsforaccount",
    "ListConnectedAccountsForAccountResponse": ".listconnectedaccountsforaccount",
    "ListConnectedAccountsForAccountResponseTypedDict": ".listconnectedaccountsforaccount",
    "ListDisputeEvidenceGlobals": ".listdisputeevidence",
    "ListDisputeEvidenceGlobalsTypedDict": ".listdisputeevidence",
    "ListDisputeEvidenceRequest": ".listdisputeevidence",
    "ListDisputeEvidenceRequestTypedDict": ".listdisputeevidence",
    "ListDisputeEvidenceResponse": ".listdisputeevidence",
    "ListDisputeEvidenceResponseTypedDict": ".listdisputeevidence",
    "ListDisputesGlobals": ".listdisputes",
    "ListDisputesGlobalsTypedDict": ".listdisputes",
    "ListDisputesRequest": ".listdisputes",
    "ListDisputesRequestTypedDict": ".listdisputes",
    "ListDisputesResponse": ".listdisputes",
    "ListDisputesResponseTypedDict": ".listdisputes",
    "ListEventTypesGlobals": ".listeventtypes",
    "ListEventTypesGlobalsTypedDict": ".listeventtypes",
    "ListEventTypesRequest": ".listeventtypes",
    "ListEventTypesRequestTypedDict": ".listeventtypes",
    "ListEventTypesResponse": ".listeventtypes",
    "ListEventTypesResponseTypedDict": ".listeventtypes",
    "ListFeePlanAgreementsGlobals": ".listfeeplanagreements",
    "ListFeePlanAgreementsGlobalsTypedDict": ".listfeeplanagreements",
    "ListFeePlanAgreementsRequest": ".listfeeplanagreements",
    "ListFeePlanAgreementsRequestTypedDict": ".listfeeplanagreements",
    "ListFeePlanAgreementsResponse": ".listfeeplanagreements",
    "ListFeePlanAgreementsResponseTypedDict": ".listfeeplanagreements",
    "ListFeePlansGlobals": ".listfeeplans",
    "ListFeePlansGlobalsTypedDict": ".listfeeplans",
    "ListFeePlansRequest": ".listfeeplans",
    "ListFeePlansRequestTypedDict": ".listfeeplans",
    "ListFeePlansResponse": ".listfeeplans",
    "ListFeePlansResponseTypedDict": ".listfeeplans",
    "ListFeeRevenueGlobals": ".listfeerevenue",
    "ListFeeRevenueGlobalsTypedDict": ".listfeerevenue",
    "ListFeeRevenueRequest": ".listfeerevenue",
    "ListFeeRevenueRequestTypedDict": ".listfeerevenue",
    "ListFeeRevenueResponse": ".listfeerevenue",
    "ListFeeRevenueResponseTypedDict": ".listfeerevenue",
    "ListFeesFetchGlobals": ".listfeesfetch",
    "ListFeesFetchGlobalsTypedDict": ".listfeesfetch",
    "ListFeesFetchRequest": ".listfeesfetch",
    "ListFeesFetchRequestTypedDict": ".listfeesfetch",
    "ListFeesFetchResponse": ".listfeesfetch",
    "ListFeesFetchResponseTypedDict": ".listfeesfetch",
    "ListFilesGlobals": ".listfiles",
    "ListFilesGlobalsTypedDict": ".listfiles",
    "ListFilesRequest": ".listfiles",
    "ListFilesRequestTypedDict": ".listfiles",
    "ListFilesResponse": ".listfiles",
    "ListFilesResponseTypedDict": ".listfiles",
    "ListImageMetadataGlobals": ".listimagemetadata",
    "ListImageMetadataGlobalsTypedDict": ".listimagemetadata",
    "ListImageMetadataRequest": ".listimagemetadata",
    "ListImageMetadataRequestTypedDict": ".listimagemetadata",
    "ListImageMetadataResponse": ".listimagemetadata",
    "ListImageMetadataResponseTypedDict": ".listimagemetadata",
    "ListIndustriesGlobals": ".listindustries",
    "ListIndustriesGlobalsTypedDict": ".listindustries",
    "ListIndustriesRequest": ".listindustries",
    "ListIndustriesRequestTypedDict": ".listindustries",
    "ListIndustriesResponse": ".listindustries",
    "ListIndustriesResponseTypedDict": ".listindustries",
    "ListInstitutionsGlobals": ".listinstitutions",
    "ListInstitutionsGlobalsTypedDict": ".listinstitutions",
    "ListInstitutionsRequest": ".listinstitutions",
    "ListInstitutionsRequestTypedDict": ".listinstitutions",
    "ListInstitutionsResponse": ".listinstitutions",
    "ListInstitutionsResponseTypedDict": ".listinstitutions",
    "ListInvoicePaymentsGlobals": ".listinvoicepayments",
    "ListInvoicePaymentsGlobalsTypedDict": ".listinvoicepayments",
    "ListInvoicePaymentsRequest": ".listinvoicepayments",
    "ListInvoicePaymentsRequestTypedDict": ".listinvoicepayments",
    "ListInvoicePaymentsResponse": ".listinvoicepayments",
    "ListInvoicePaymentsResponseTypedDict": ".listinvoicepayments",
    "ListInvoicesGlobals": ".listinvoices",
    "ListInvoicesGlobalsTypedDict": ".listinvoices",
    "ListInvoicesRequest": ".listinvoices",
    "ListInvoicesRequestTypedDict": ".listinvoices",
    "ListInvoicesResponse": ".listinvoices",
    "ListInvoicesResponseTypedDict": ".listinvoices",
    "ListIssuedCardAuthorizationEventsGlobals": ".listissuedcardauthorizationevents",
    "ListIssuedCardAuthorizationEventsGlobalsTypedDict": ".listissuedcardauthorizationevents",
    "ListIssuedCardAuthorizationEventsRequest": ".listissuedcardauthorizationevents",
    "ListIssuedCardAuthorizationEventsRequestTypedDict": ".listissuedcardauthorizationevents",
    "ListIssuedCardAuthorizationEventsResponse": ".listissuedcardauthorizationevents",
    "ListIssuedCardAuthorizationEventsResponseTypedDict": ".listissuedcardauthorizationevents",
    "ListIssuedCardAuthorizationsGlobals": ".listissuedcardauthorizations",
    "ListIssuedCardAuthorizationsGlobalsTypedDict": ".listissuedcardauthorizations",
    "ListIssuedCardAuthorizationsRequest": ".listissuedcardauthorizations",
    "ListIssuedCardAuthorizationsRequestTypedDict": ".listissuedcardauthorizations",
    "ListIssuedCardAuthorizationsResponse": ".listissuedcardauthorizations",
    "ListIssuedCardAuthorizationsResponseTypedDict": ".listissuedcardauthorizations",
    "ListIssuedCardsGlobals": ".listissuedcards",
    "ListIssuedCardsGlobalsTypedDict": ".listissuedcards",
    "ListIssuedCardsRequest": ".listissuedcards",
    "ListIssuedCardsRequestTypedDict": ".listissuedcards",
    "ListIssuedCardsResponse": ".listissuedcards",
    "ListIssuedCardsResponseTypedDict": ".listissuedcards",
    "ListIssuedCardTransactionsGlobals": ".listissuedcardtransactions",
    "ListIssuedCardTransactionsGlobalsTypedDict": ".listissuedcardtransactions",
    "ListIssuedCardTransactionsRequest": ".listissuedcardtransactions",
    "ListIssuedCardTransactionsRequestTypedDict": ".listissuedcardtransactions",
    "ListIssuedCardTransactionsResponse": ".listissuedcardtransactions",
    "ListIssuedCardTransactionsResponseTypedDict": ".listissuedcardtransactions",
    "ListOnboardingInvitesGlobals": ".listonboardinginvites",
    "ListOnboardingInvitesGlobalsTypedDict": ".listonboardinginvites",
    "ListOnboardingInvitesRequest": ".listonboardinginvites",
    "ListOnboardingInvitesRequestTypedDict": ".listonboardinginvites",
    "ListOnboardingInvitesResponse": ".listonboardinginvites",
    "ListOnboardingInvitesResponseTypedDict": ".listonboardinginvites",
    "ListPartnerPricingAgreementsGlobals": ".listpartnerpricingagreements",
    "ListPartnerPricingAgreementsGlobalsTypedDict": ".listpartnerpricingagreements",
    "ListPartnerPricingAgreementsRequest": ".listpartnerpricingagreements",
    "ListPartnerPricingAgreementsRequestTypedDict": ".listpartnerpricingagreements",
    "ListPartnerPricingAgreementsResponse": ".listpartnerpricingagreements",
    "ListPartnerPricingAgreementsResponseTypedDict": ".listpartnerpricingagreements",
    "ListPaymentLinksGlobals": ".listpaymentlinks",
    "ListPaymentLinksGlobalsTypedDict": ".listpaymentlinks",
    "ListPaymentLinksRequest": ".listpaymentlinks",
    "ListPaymentLinksRequestTypedDict": ".listpaymentlinks",
    "ListPaymentLinksResponse": ".listpaymentlinks",
    "ListPaymentLinksResponseTypedDict": ".listpaymentlinks",
    "ListPaymentMethodsGlobals": ".listpaymentmethods",
    "ListPaymentMethodsGlobalsTypedDict": ".listpaymentmethods",
    "ListPaymentMethodsRequest": ".listpaymentmethods",
    "ListPaymentMethodsRequestTypedDict": ".listpaymentmethods",
    "ListPaymentMethodsResponse": ".listpaymentmethods",
    "ListPaymentMethodsResponseTypedDict": ".listpaymentmethods",
    "ListProductsGlobals": ".listproducts",
    "ListProductsGlobalsTypedDict": ".listproducts",
    "ListProductsRequest": ".listproducts",
    "ListProductsRequestTypedDict": ".listproducts",
    "ListProductsResponse": ".listproducts",
    "ListProductsResponseTypedDict": ".listproducts",
    "ListReceiptsGlobals": ".listreceipts",
    "ListReceiptsGlobalsTypedDict": ".listreceipts",
    "ListReceiptsRequest": ".listreceipts",
    "ListReceiptsRequestTypedDict": ".listreceipts",
    "ListReceiptsResponse": ".listreceipts",
    "ListReceiptsResponseTypedDict": ".listreceipts",
    "ListRefundsGlobals": ".listrefunds",
    "ListRefundsGlobalsTypedDict": ".listrefunds",
    "ListRefundsRequest": ".listrefunds",
    "ListRefundsRequestTypedDict": ".listrefunds",
    "ListRefundsResponse": ".listrefunds",
    "ListRefundsResponseTypedDict": ".listrefunds",
    "ListRepresentativesGlobals": ".listrepresentatives",
    "ListRepresentativesGlobalsTypedDict": ".listrepresentatives",
    "ListRepresentativesRequest": ".listrepresentatives",
    "ListRepresentativesRequestTypedDict": ".listrepresentatives",
    "ListRepresentativesResponse": ".listrepresentatives",
    "ListRepresentativesResponseTypedDict": ".listrepresentatives",
    "ListResidualFeesGlobals": ".listresidualfees",
    "ListResidualFeesGlobalsTypedDict": ".listresidualfees",
    "ListResidualFeesRequest": ".listresidualfees",
    "ListResidualFeesRequestTypedDict": ".listresidualfees",
    "ListResidualFeesResponse": ".listresidualfees",
    "ListResidualFeesResponseTypedDict": ".listresidualfees",
    "ListResidualsGlobals": ".listresiduals",
    "ListResidualsGlobalsTypedDict": ".listresiduals",
    "ListResidualsRequest": ".listresiduals",
    "ListResidualsRequestTypedDict": ".listresiduals",
    "ListResidualsResponse": ".listresiduals",
    "ListResidualsResponseTypedDict": ".listresiduals",
    "Hydrate": ".listschedules",
    "ListSchedulesGlobals": ".listschedules",
    "ListSchedulesGlobalsTypedDict": ".listschedules",
    "ListSchedulesRequest": ".listschedules",
    "ListSchedulesRequestTypedDict": ".listschedules",
    "ListSchedulesResponse": ".listschedules",
    "ListSchedulesResponseTypedDict": ".listschedules",
    "ListStatementsGlobals": ".liststatements",
    "ListStatementsGlobalsTypedDict": ".liststatements",
    "ListStatementsRequest": ".liststatements",
    "ListStatementsRequestTypedDict": ".liststatements",
    "ListStatementsResponse": ".liststatements",
    "ListStatementsResponseTypedDict": ".liststatements",
    "ListSweepConfigsGlobals": ".listsweepconfigs",
    "ListSweepConfigsGlobalsTypedDict": ".listsweepconfigs",
    "ListSweepConfigsRequest": ".listsweepconfigs",
    "ListSweepConfigsRequestTypedDict": ".listsweepconfigs",
    "ListSweepConfigsResponse": ".listsweepconfigs",
    "ListSweepConfigsResponseTypedDict": ".listsweepconfigs",
    "ListSweepsGlobals": ".listsweeps",
    "ListSweepsGlobalsTypedDict": ".listsweeps",
    "ListSweepsRequest": ".listsweeps",
    "ListSweepsRequestTypedDict": ".listsweeps",
    "ListSweepsResponse": ".listsweeps",
    "ListSweepsResponseTypedDict": ".listsweeps",
    "ListTerminalApplicationsGlobals": ".listterminalapplications",
    "ListTerminalApplicationsGlobalsTypedDict": ".listterminalapplications",
    "ListTerminalApplicationsRequest": ".listterminalapplications",
    "ListTerminalApplicationsRequestTypedDict": ".listterminalapplications",
    "ListTerminalApplicationsResponse": ".listterminalapplications",
    "ListTerminalApplicationsResponseTypedDict": ".listterminalapplications",
    "ListTicketMessagesGlobals": ".listticketmessages",
    "ListTicketMessagesGlobalsTypedDict": ".listticketmessages",
    "ListTicketMessagesRequest": ".listticketmessages",
    "ListTicketMessagesRequestTypedDict": ".listticketmessages",
    "ListTicketMessagesResponse": ".listticketmessages",
    "ListTicketMessagesResponseTypedDict": ".listticketmessages",
    "ListTicketsGlobals": ".listtickets",
    "ListTicketsGlobalsTypedDict": ".listtickets",
    "ListTicketsRequest": ".listtickets",
    "ListTicketsRequestTypedDict": ".listtickets",
    "ListTicketsResponse": ".listtickets",
    "ListTicketsResponseBody": ".listtickets",
    "ListTicketsResponseBodyTypedDict": ".listtickets",
    "ListTicketsResponseTypedDict": ".listtickets",
    "ListTransfersGlobals": ".listtransfers",
    "ListTransfersGlobalsTypedDict": ".listtransfers",
    "ListTransfersRequest": ".listtransfers",
    "ListTransfersRequestTypedDict": ".listtransfers",
    "ListTransfersResponse": ".listtransfers",
    "ListTransfersResponseTypedDict": ".listtransfers",
    "ListWalletsGlobals": ".listwallets",
    "ListWalletsGlobalsTypedDict": ".listwallets",
    "ListWalletsRequest": ".listwallets",
    "ListWalletsRequestTypedDict": ".listwallets",
    "ListWalletsResponse": ".listwallets",
    "ListWalletsResponseTypedDict": ".listwallets",
    "ListWalletTransactionsGlobals": ".listwallettransactions",
    "ListWalletTransactionsGlobalsTypedDict": ".listwallettransactions",
    "ListWalletTransactionsRequest": ".listwallettransactions",
    "ListWalletTransactionsRequestTypedDict": ".listwallettransactions",
    "ListWalletTransactionsResponse": ".listwallettransactions",
    "ListWalletTransactionsResponseTypedDict": ".listwallettransactions",
    "ListWebhooksGlobals": ".listwebhooks",
    "ListWebhooksGlobalsTypedDict": ".listwebhooks",
    "ListWebhooksRequest": ".listwebhooks",
    "ListWebhooksRequestTypedDict": ".listwebhooks",
    "ListWebhooksResponse": ".listwebhooks",
    "ListWebhooksResponseTypedDict": ".listwebhooks",
    "PingGlobals": ".ping",
    "PingGlobalsTypedDict": ".ping",
    "PingRequest": ".ping",
    "PingRequestTypedDict": ".ping",
    "PingResponse": ".ping",
    "PingResponseTypedDict": ".ping",
    "PingWebhookGlobals": ".pingwebhook",
    "PingWebhookGlobalsTypedDict": ".pingwebhook",
    "PingWebhookRequest": ".pingwebhook",
    "PingWebhookRequestTypedDict": ".pingwebhook",
    "PingWebhookResponse": ".pingwebhook",
    "PingWebhookResponseTypedDict": ".pingwebhook",
    "RegisterApplePayMerchantDomainsGlobals": ".registerapplepaymerchantdomains",
    "RegisterApplePayMerchantDomainsGlobalsTypedDict": ".registerapplepaymerchantdomains",
    "RegisterApplePayMerchantDomainsRequest": ".registerapplepaymerchantdomains",
    "RegisterApplePayMerchantDomainsRequestTypedDict": ".registerapplepaymerchantdomains",
    "RegisterApplePayMerchantDomainsResponse": ".registerapplepaymerchantdomains",
    "RegisterApplePayMerchantDomainsResponseTypedDict": ".registerapplepaymerchantdomains",
    "RequestCapabilitiesGlobals": ".requestcapabilities",
    "RequestCapabilitiesGlobalsTypedDict": ".requestcapabilities",
    "RequestCapabilitiesRequest": ".requestcapabilities",
    "RequestCapabilitiesRequestTypedDict": ".requestcapabilities",
    "RequestCapabilitiesResponse": ".requestcapabilities",
    "RequestCapabilitiesResponseTypedDict": ".requestcapabilities",
    "RequestCardGlobals": ".requestcard",
    "RequestCardGlobalsTypedDict": ".requestcard",
    "RequestCardRequest": ".requestcard",
    "RequestCardRequestTypedDict": ".requestcard",
    "RequestCardResponse": ".requestcard",
    "RequestCardResponseTypedDict": ".requestcard",
    "RetrieveFeesGlobals": ".retrievefees",
    "RetrieveFeesGlobalsTypedDict": ".retrievefees",
    "RetrieveFeesRequest": ".retrievefees",
    "RetrieveFeesRequestTypedDict": ".retrievefees",
    "RetrieveFeesResponse": ".retrievefees",
    "RetrieveFeesResponseTypedDict": ".retrievefees",
    "RevokeAccessTokenGlobals": ".revokeaccesstoken",
    "RevokeAccessTokenGlobalsTypedDict": ".revokeaccesstoken",
    "RevokeAccessTokenResponse": ".revokeaccesstoken",
    "RevokeAccessTokenResponseTypedDict": ".revokeaccesstoken",
    "RevokeOnboardingInviteGlobals": ".revokeonboardinginvite",
    "RevokeOnboardingInviteGlobalsTypedDict": ".revokeonboardinginvite",
    "RevokeOnboardingInviteRequest": ".revokeonboardinginvite",
    "RevokeOnboardingInviteRequestTypedDict": ".revokeonboardinginvite",
    "RevokeOnboardingInviteResponse": ".revokeonboardinginvite",
    "RevokeOnboardingInviteResponseTypedDict": ".revokeonboardinginvite",
    "SaveUnderwritingGlobals": ".saveunderwriting",
    "SaveUnderwritingGlobalsTypedDict": ".saveunderwriting",
    "SaveUnderwritingRequest": ".saveunderwriting",
    "SaveUnderwritingRequestTypedDict": ".saveunderwriting",
    "SaveUnderwritingResponse": ".saveunderwriting",
    "SaveUnderwritingResponseTypedDict": ".saveunderwriting",
    "SearchInstitutionsGlobals": ".searchinstitutions",
    "SearchInstitutionsGlobalsTypedDict": ".searchinstitutions",
    "SearchInstitutionsRequest": ".searchinstitutions",
    "SearchInstitutionsRequestTypedDict": ".searchinstitutions",
    "SearchInstitutionsResponse": ".searchinstitutions",
    "SearchInstitutionsResponseTypedDict": ".searchinstitutions",
    "SubmitDisputeEvidenceGlobals": ".submitdisputeevidence",
    "SubmitDisputeEvidenceGlobalsTypedDict": ".submitdisputeevidence",
    "SubmitDisputeEvidenceRequest": ".submitdisputeevidence",
    "SubmitDisputeEvidenceRequestTypedDict": ".submitdisputeevidence",
    "SubmitDisputeEvidenceResponse": ".submitdisputeevidence",
    "SubmitDisputeEvidenceResponseTypedDict": ".submitdisputeevidence",
    "TestEndToEndTokenGlobals": ".testendtoendtoken",
    "TestEndToEndTokenGlobalsTypedDict": ".testendtoendtoken",
    "TestEndToEndTokenResponse": ".testendtoendtoken",
    "TestEndToEndTokenResponseTypedDict": ".testendtoendtoken",
    "UpdateAccountGlobals": ".updateaccount",
    "UpdateAccountGlobalsTypedDict": ".updateaccount",
    "UpdateAccountRequest": ".updateaccount",
    "UpdateAccountRequestTypedDict": ".updateaccount",
    "UpdateAccountResponse": ".updateaccount",
    "UpdateAccountResponseTypedDict": ".updateaccount",
    "UpdateApplePayMerchantDomainsGlobals": ".updateapplepaymerchantdomains",
    "UpdateApplePayMerchantDomainsGlobalsTypedDict": ".updateapplepaymerchantdomains",
    "UpdateApplePayMerchantDomainsRequest": ".updateapplepaymerchantdomains",
    "UpdateApplePayMerchantDomainsRequestTypedDict": ".updateapplepaymerchantdomains",
    "UpdateApplePayMerchantDomainsResponse": ".updateapplepaymerchantdomains",
    "UpdateApplePayMerchantDomainsResponseTypedDict": ".updateapplepaymerchantdomains",
    "UpdateCardGlobals": ".updatecard",
    "UpdateCardGlobalsTypedDict": ".updatecard",
    "UpdateCardRequest": ".updatecard",
    "UpdateCardRequestTypedDict": ".updatecard",
    "UpdateCardResponse": ".updatecard",
    "UpdateCardResponseTypedDict": ".updatecard",
    "UpdateDisputeEvidenceGlobals": ".updatedisputeevidence",
    "UpdateDisputeEvidenceGlobalsTypedDict": ".updatedisputeevidence",
    "UpdateDisputeEvidenceRequest": ".updatedisputeevidence",
    "UpdateDisputeEvidenceRequestTypedDict": ".updatedisputeevidence",
    "UpdateDisputeEvidenceResponse": ".updatedisputeevidence",
    "UpdateDisputeEvidenceResponseTypedDict": ".updatedisputeevidence",
    "UpdateImageGlobals": ".updateimage",
    "UpdateImageGlobalsTypedDict": ".updateimage",
    "UpdateImageRequest": ".updateimage",
    "UpdateImageRequestTypedDict": ".updateimage",
    "UpdateImageResponse": ".updateimage",
    "UpdateImageResponseTypedDict": ".updateimage",
    "UpdateImageMetadataGlobals": ".updateimagemetadata",
    "UpdateImageMetadataGlobalsTypedDict": ".updateimagemetadata",
    "UpdateImageMetadataRequest": ".updateimagemetadata",
    "UpdateImageMetadataRequestTypedDict": ".updateimagemetadata",
    "UpdateImageMetadataResponse": ".updateimagemetadata",
    "UpdateImageMetadataResponseTypedDict": ".updateimagemetadata",
    "UpdateInvoiceGlobals": ".updateinvoice",
    "UpdateInvoiceGlobalsTypedDict": ".updateinvoice",
    "UpdateInvoiceRequest": ".updateinvoice",
    "UpdateInvoiceRequestTypedDict": ".updateinvoice",
    "UpdateInvoiceResponse": ".updateinvoice",
    "UpdateInvoiceResponseTypedDict": ".updateinvoice",
    "UpdateIssuedCardGlobals": ".updateissuedcard",
    "UpdateIssuedCardGlobalsTypedDict": ".updateissuedcard",
    "UpdateIssuedCardRequest": ".updateissuedcard",
    "UpdateIssuedCardRequestTypedDict": ".updateissuedcard",
    "UpdateIssuedCardResponse": ".updateissuedcard",
    "UpdateIssuedCardResponseTypedDict": ".updateissuedcard",
    "UpdatePaymentLinkGlobals": ".updatepaymentlink",
    "UpdatePaymentLinkGlobalsTypedDict": ".updatepaymentlink",
    "UpdatePaymentLinkRequest": ".updatepaymentlink",
    "UpdatePaymentLinkRequestTypedDict": ".updatepaymentlink",
    "UpdatePaymentLinkResponse": ".updatepaymentlink",
    "UpdatePaymentLinkResponseTypedDict": ".updatepaymentlink",
    "UpdateProductGlobals": ".updateproduct",
    "UpdateProductGlobalsTypedDict": ".updateproduct",
    "UpdateProductRequest": ".updateproduct",
    "UpdateProductRequestTypedDict": ".updateproduct",
    "UpdateProductResponse": ".updateproduct",
    "UpdateProductResponseTypedDict": ".updateproduct",
    "UpdateRepresentativeGlobals": ".updaterepresentative",
    "UpdateRepresentativeGlobalsTypedDict": ".updaterepresentative",
    "UpdateRepresentativeRequest": ".updaterepresentative",
    "UpdateRepresentativeRequestTypedDict": ".updaterepresentative",
    "UpdateRepresentativeResponse": ".updaterepresentative",
    "UpdateRepresentativeResponseTypedDict": ".updaterepresentative",
    "UpdateScheduleGlobals": ".updateschedule",
    "UpdateScheduleGlobalsTypedDict": ".updateschedule",
    "UpdateScheduleRequest": ".updateschedule",
    "UpdateScheduleRequestTypedDict": ".updateschedule",
    "UpdateScheduleResponse": ".updateschedule",
    "UpdateScheduleResponseTypedDict": ".updateschedule",
    "UpdateSweepConfigGlobals": ".updatesweepconfig",
    "UpdateSweepConfigGlobalsTypedDict": ".updatesweepconfig",
    "UpdateSweepConfigRequest": ".updatesweepconfig",
    "UpdateSweepConfigRequestTypedDict": ".updatesweepconfig",
    "UpdateSweepConfigResponse": ".updatesweepconfig",
    "UpdateSweepConfigResponseTypedDict": ".updatesweepconfig",
    "UpdateTicketGlobals": ".updateticket",
    "UpdateTicketGlobalsTypedDict": ".updateticket",
    "UpdateTicketRequest": ".updateticket",
    "UpdateTicketRequestTypedDict": ".updateticket",
    "UpdateTicketResponse": ".updateticket",
    "UpdateTicketResponseTypedDict": ".updateticket",
    "UpdateTransferGlobals": ".updatetransfer",
    "UpdateTransferGlobalsTypedDict": ".updatetransfer",
    "UpdateTransferRequest": ".updatetransfer",
    "UpdateTransferRequestTypedDict": ".updatetransfer",
    "UpdateTransferResponse": ".updatetransfer",
    "UpdateTransferResponseTypedDict": ".updatetransfer",
    "UpdateWalletGlobals": ".updatewallet",
    "UpdateWalletGlobalsTypedDict": ".updatewallet",
    "UpdateWalletRequest": ".updatewallet",
    "UpdateWalletRequestTypedDict": ".updatewallet",
    "UpdateWalletResponse": ".updatewallet",
    "UpdateWalletResponseTypedDict": ".updatewallet",
    "UpdateWebhookGlobals": ".updatewebhook",
    "UpdateWebhookGlobalsTypedDict": ".updatewebhook",
    "UpdateWebhookRequest": ".updatewebhook",
    "UpdateWebhookRequestTypedDict": ".updatewebhook",
    "UpdateWebhookResponse": ".updatewebhook",
    "UpdateWebhookResponseTypedDict": ".updatewebhook",
    "UploadDisputeEvidenceFileGlobals": ".uploaddisputeevidencefile",
    "UploadDisputeEvidenceFileGlobalsTypedDict": ".uploaddisputeevidencefile",
    "UploadDisputeEvidenceFileRequest": ".uploaddisputeevidencefile",
    "UploadDisputeEvidenceFileRequestTypedDict": ".uploaddisputeevidencefile",
    "UploadDisputeEvidenceFileResponse": ".uploaddisputeevidencefile",
    "UploadDisputeEvidenceFileResponseTypedDict": ".uploaddisputeevidencefile",
    "UploadDisputeEvidenceTextGlobals": ".uploaddisputeevidencetext",
    "UploadDisputeEvidenceTextGlobalsTypedDict": ".uploaddisputeevidencetext",
    "UploadDisputeEvidenceTextRequest": ".uploaddisputeevidencetext",
    "UploadDisputeEvidenceTextRequestTypedDict": ".uploaddisputeevidencetext",
    "UploadDisputeEvidenceTextResponse": ".uploaddisputeevidencetext",
    "UploadDisputeEvidenceTextResponseTypedDict": ".uploaddisputeevidencetext",
    "UploadFileGlobals": ".uploadfile",
    "UploadFileGlobalsTypedDict": ".uploadfile",
    "UploadFileRequest": ".uploadfile",
    "UploadFileRequestTypedDict": ".uploadfile",
    "UploadFileResponse": ".uploadfile",
    "UploadFileResponseTypedDict": ".uploadfile",
    "UploadImageGlobals": ".uploadimage",
    "UploadImageGlobalsTypedDict": ".uploadimage",
    "UploadImageRequest": ".uploadimage",
    "UploadImageRequestTypedDict": ".uploadimage",
    "UploadImageResponse": ".uploadimage",
    "UploadImageResponseTypedDict": ".uploadimage",
    "UpsertBrandGlobals": ".upsertbrand",
    "UpsertBrandGlobalsTypedDict": ".upsertbrand",
    "UpsertBrandRequest": ".upsertbrand",
    "UpsertBrandRequestTypedDict": ".upsertbrand",
    "UpsertBrandResponse": ".upsertbrand",
    "UpsertBrandResponseTypedDict": ".upsertbrand",
    "UpsertUnderwritingGlobals": ".upsertunderwriting",
    "UpsertUnderwritingGlobalsTypedDict": ".upsertunderwriting",
    "UpsertUnderwritingRequest": ".upsertunderwriting",
    "UpsertUnderwritingRequestTypedDict": ".upsertunderwriting",
    "UpsertUnderwritingResponse": ".upsertunderwriting",
    "UpsertUnderwritingResponseTypedDict": ".upsertunderwriting",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
